@@ -13,14 +13,16 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "stdinc.h"
-#include "DCPlusPlus.h"
 
 #include "AdcHub.h"
 
+#include <boost/scoped_array.hpp>
+#include <boost/format.hpp>
+
 #include "ChatMessage.h"
 #include "ClientManager.h"
 #include "ShareManager.h"
@@ -34,10 +36,14 @@
 #include "LogManager.h"
 #include "ThrottleManager.h"
 #include "UploadManager.h"
+#include "format.h"
+
 #include <cmath>
 
 namespace dcpp {
 
+using std::make_pair;
+
 const string AdcHub::CLIENT_PROTOCOL("ADC/1.0");
 const string AdcHub::SECURE_CLIENT_PROTOCOL_TEST("ADCS/0.10");
 const string AdcHub::ADCS_FEATURE("ADC0");
@@ -50,7 +56,9 @@ const string AdcHub::BAS0_SUPPORT("ADBAS0");
 const string AdcHub::TIGR_SUPPORT("ADTIGR");
 const string AdcHub::UCM0_SUPPORT("ADUCM0");
 const string AdcHub::BLO0_SUPPORT("ADBLO0");
+#ifdef WITH_DHT
 const string AdcHub::DHT0_SUPPORT("ADDHT0");
+#endif
 
 const vector<StringList> AdcHub::searchExts;
 
@@ -58,7 +66,7 @@ AdcHub::AdcHub(const string& aHubURL, bool secure) : Client(aHubURL, '\n', secur
     TimerManager::getInstance()->addListener(this);
 }
 
-AdcHub::~AdcHub() throw() {
+AdcHub::~AdcHub() {
     TimerManager::getInstance()->removeListener(this);
     clearUsers();
 }
@@ -129,7 +137,7 @@ void AdcHub::clearUsers() {
     }
 }
 
-void AdcHub::handle(AdcCommand::INF, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::INF, AdcCommand& c) noexcept {
     if(c.getParameters().empty())
         return;
 
@@ -200,7 +208,7 @@ void AdcHub::handle(AdcCommand::INF, AdcCommand& c) throw() {
     }
 }
 
-void AdcHub::handle(AdcCommand::SUP, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::SUP, AdcCommand& c) noexcept {
     if(state != STATE_PROTOCOL) /** @todo SUP changes */
         return;
     bool baseOk = false;
@@ -227,7 +235,7 @@ void AdcHub::handle(AdcCommand::SUP, AdcCommand& c) throw() {
     }
 }
 
-void AdcHub::handle(AdcCommand::SID, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::SID, AdcCommand& c) noexcept {
     if(state != STATE_PROTOCOL) {
         dcdebug("Invalid state for SID\n");
         return;
@@ -242,7 +250,7 @@ void AdcHub::handle(AdcCommand::SID, AdcCommand& c) throw() {
     info(true);
 }
 
-void AdcHub::handle(AdcCommand::MSG, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::MSG, AdcCommand& c) noexcept {
     if(c.getParameters().empty())
         return;
 
@@ -253,24 +261,24 @@ void AdcHub::handle(AdcCommand::MSG, AdcCommand& c) throw() {
 
         string temp;
         if(c.getParam("PM", 1, temp)) { // add PM<group-cid> as well
-                message.to = findUser(c.getTo());
-                if(!message.to)
-            return;
+            message.to = findUser(c.getTo());
+            if(!message.to)
+                return;
 
-                message.replyTo = findUser(AdcCommand::toSID(temp));
-                if(!message.replyTo)
-                        return;
-    }
+            message.replyTo = findUser(AdcCommand::toSID(temp));
+            if(!message.replyTo)
+                return;
+        }
 
         message.thirdPerson = c.hasFlag("ME", 1);
 
         if(c.getParam("TS", 1, temp))
-                message.timestamp = Util::toInt64(temp);
+            message.timestamp = Util::toInt64(temp);
 
         fire(ClientListener::Message(), this, message);
 }
 
-void AdcHub::handle(AdcCommand::GPA, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::GPA, AdcCommand& c) noexcept {
     if(c.getParameters().empty())
         return;
     salt = c.getParam(0);
@@ -279,7 +287,7 @@ void AdcHub::handle(AdcCommand::GPA, AdcCommand& c) throw() {
     fire(ClientListener::GetPassword(), this);
 }
 
-void AdcHub::handle(AdcCommand::QUI, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::QUI, AdcCommand& c) noexcept {
     uint32_t s = AdcCommand::toSID(c.getParam(0));
 
     OnlineUser* victim = findUser(s);
@@ -295,7 +303,7 @@ void AdcHub::handle(AdcCommand::QUI, AdcCommand& c) throw() {
 
         if(source) {
             tmp = str(F_("%1% was kicked by %2%: %3%") % victim->getIdentity().getNick() %
-                source->getIdentity().getNick() % tmp);
+            source->getIdentity().getNick() % tmp);
         } else {
             tmp = str(F_("%1% was kicked: %2%") % victim->getIdentity().getNick() % tmp);
         }
@@ -318,7 +326,7 @@ void AdcHub::handle(AdcCommand::QUI, AdcCommand& c) throw() {
             }
         }
                 if(!victim && c.getParam("MS", 1, tmp)) {
-                        fire(ClientListener::StatusMessage(), this, tmp, ClientListener::FLAG_NORMAL);
+                    fire(ClientListener::StatusMessage(), this, tmp, ClientListener::FLAG_NORMAL);
                 }
         if(c.getParam("RD", 1, tmp)) {
             fire(ClientListener::Redirect(), this, tmp);
@@ -326,11 +334,11 @@ void AdcHub::handle(AdcCommand::QUI, AdcCommand& c) throw() {
     }
 }
 
-void AdcHub::handle(AdcCommand::CTM, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::CTM, AdcCommand& c) noexcept {
     OnlineUser* u = findUser(c.getFrom());
     if(!u || u->getUser() == ClientManager::getInstance()->getMe())
         return;
-        if(c.getParameters().size() < 3)
+    if(c.getParameters().size() < 3)
         return;
 
     const string& protocol = c.getParam(0);
@@ -355,7 +363,7 @@ void AdcHub::handle(AdcCommand::CTM, AdcCommand& c) throw() {
     ConnectionManager::getInstance()->adcConnect(*u, static_cast<uint16_t>(Util::toInt(port)), token, secure);
 }
 
-void AdcHub::handle(AdcCommand::RCM, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::RCM, AdcCommand& c) noexcept {
     if(c.getParameters().size() < 2) {
         return;
     }
@@ -393,7 +401,7 @@ void AdcHub::handle(AdcCommand::RCM, AdcCommand& c) throw() {
    return;
 }
 
-void AdcHub::handle(AdcCommand::CMD, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::CMD, AdcCommand& c) noexcept {
     if(c.getParameters().size() < 1)
         return;
     const string& name = c.getParam(0);
@@ -420,7 +428,7 @@ void AdcHub::handle(AdcCommand::CMD, AdcCommand& c) throw() {
     fire(ClientListener::HubUserCommand(), this, (int)(once ? UserCommand::TYPE_RAW_ONCE : UserCommand::TYPE_RAW), ctx, name, txt);
 }
 
-void AdcHub::sendUDP(const AdcCommand& cmd) throw() {
+void AdcHub::sendUDP(const AdcCommand& cmd) noexcept {
     string command;
     string ip;
     uint16_t port;
@@ -447,11 +455,11 @@ void AdcHub::sendUDP(const AdcCommand& cmd) throw() {
     }
 }
 
-void AdcHub::handle(AdcCommand::STA, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::STA, AdcCommand& c) noexcept {
     if(c.getParameters().size() < 2)
         return;
 
-        OnlineUser* u = c.getFrom() == AdcCommand::HUB_SID ? &getUser(c.getFrom(), CID()) : findUser(c.getFrom());
+    OnlineUser* u = c.getFrom() == AdcCommand::HUB_SID ? &getUser(c.getFrom(), CID()) : findUser(c.getFrom());
     if(!u)
         return;
 
@@ -460,24 +468,24 @@ void AdcHub::handle(AdcCommand::STA, AdcCommand& c) throw() {
         return;
     }
 
-        switch(Util::toInt(c.getParam(0).substr(1))) {
+    switch(Util::toInt(c.getParam(0).substr(1))) {
 
-        case AdcCommand::ERROR_BAD_PASSWORD:
-                {
-        setPassword(Util::emptyString);
-                        break;
-                }
+    case AdcCommand::ERROR_BAD_PASSWORD:
+            {
+                setPassword(Util::emptyString);
+                break;
+            }
 
-        case AdcCommand::ERROR_COMMAND_ACCESS:
-                {
-                        string tmp;
-                        if(c.getParam("FC", 1, tmp) && tmp.size() == 4)
-                                forbiddenCommands.insert(AdcCommand::toFourCC(tmp.c_str()));
-                        break;
-                }
+    case AdcCommand::ERROR_COMMAND_ACCESS:
+            {
+                string tmp;
+                if(c.getParam("FC", 1, tmp) && tmp.size() == 4)
+                    forbiddenCommands.insert(AdcCommand::toFourCC(tmp.c_str()));
+                break;
+            }
 
-        case AdcCommand::ERROR_PROTOCOL_UNSUPPORTED:
-                {
+    case AdcCommand::ERROR_PROTOCOL_UNSUPPORTED:
+            {
                 string tmp;
                 if(c.getParam("PR", 1, tmp)) {
                     if(tmp == CLIENT_PROTOCOL) {
@@ -490,13 +498,13 @@ void AdcHub::handle(AdcCommand::STA, AdcCommand& c) throw() {
                 ConnectionManager::getInstance()->force(u->getUser());
                 }
                 return;
-                }
-        }
+            }
+    }
     ChatMessage message = { c.getParam(1), u };
     fire(ClientListener::Message(), this, message);
 }
 
-void AdcHub::handle(AdcCommand::SCH, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::SCH, AdcCommand& c) noexcept {
     OnlineUser* ou = findUser(c.getFrom());
     if(!ou) {
         dcdebug("Invalid user in AdcHub::onSCH\n");
@@ -506,7 +514,7 @@ void AdcHub::handle(AdcCommand::SCH, AdcCommand& c) throw() {
     fire(ClientListener::AdcSearch(), this, c, ou->getUser()->getCID());
 }
 
-void AdcHub::handle(AdcCommand::RES, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::RES, AdcCommand& c) noexcept {
     OnlineUser* ou = findUser(c.getFrom());
     if(!ou) {
         dcdebug("Invalid user in AdcHub::onRES\n");
@@ -515,7 +523,7 @@ void AdcHub::handle(AdcCommand::RES, AdcCommand& c) throw() {
     SearchManager::getInstance()->onRES(c, ou->getUser());
 }
 
-void AdcHub::handle(AdcCommand::PSR, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::PSR, AdcCommand& c) noexcept {
     OnlineUser* ou = findUser(c.getFrom());
     if(!ou) {
         dcdebug("Invalid user in AdcHub::onPSR\n");
@@ -524,7 +532,7 @@ void AdcHub::handle(AdcCommand::PSR, AdcCommand& c) throw() {
     SearchManager::getInstance()->onPSR(c, ou->getUser());
 }
 
-void AdcHub::handle(AdcCommand::GET, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::GET, AdcCommand& c) noexcept {
     if(c.getParameters().size() < 5) {
         if(c.getParameters().size() > 0) {
             if(c.getParam(0) == "blom") {
@@ -581,65 +589,65 @@ void AdcHub::handle(AdcCommand::GET, AdcCommand& c) throw() {
         }
     }
 }
-void AdcHub::handle(AdcCommand::NAT, AdcCommand& c) throw() {
+void AdcHub::handle(AdcCommand::NAT, AdcCommand& c) noexcept {
     if (!BOOLSETTING(ALLOW_NATT))
         return;
 
-       OnlineUser* u = findUser(c.getFrom());
-       if(!u || u->getUser() == ClientManager::getInstance()->getMe() || c.getParameters().size() < 3)
-               return;
+    OnlineUser* u = findUser(c.getFrom());
+    if(!u || u->getUser() == ClientManager::getInstance()->getMe() || c.getParameters().size() < 3)
+        return;
 
-       const string& protocol = c.getParam(0);
-       const string& port = c.getParam(1);
-       const string& token = c.getParam(2);
+    const string& protocol = c.getParam(0);
+    const string& port = c.getParam(1);
+    const string& token = c.getParam(2);
 
-       // bool secure = secureAvail(c.getFrom(), protocol, token);
-       bool secure = false;
-       if(protocol == CLIENT_PROTOCOL) {
-               // Nothing special
-       } else if(protocol == SECURE_CLIENT_PROTOCOL_TEST && CryptoManager::getInstance()->TLSOk()) {
-               secure = true;
-       } else {
-               unknownProtocol(c.getFrom(), protocol, token);
-               return;
-       }
+    // bool secure = secureAvail(c.getFrom(), protocol, token);
+    bool secure = false;
+    if(protocol == CLIENT_PROTOCOL) {
+        // Nothing special
+    } else if(protocol == SECURE_CLIENT_PROTOCOL_TEST && CryptoManager::getInstance()->TLSOk()) {
+        secure = true;
+    } else {
+        unknownProtocol(c.getFrom(), protocol, token);
+        return;
+    }
 
-       // Trigger connection attempt sequence locally ...
-       dcdebug("triggering connecting attempt in NAT: remote port = %s, local IP = %s, local port = %d\n", port.c_str(), sock->getLocalIp().c_str(), sock->getLocalPort());
-       ConnectionManager::getInstance()->adcConnect(*u, static_cast<uint16_t>(Util::toInt(port)), sock->getLocalPort(), BufferedSocket::NAT_CLIENT, token, secure);
+    // Trigger connection attempt sequence locally ...
+    dcdebug("triggering connecting attempt in NAT: remote port = %s, local IP = %s, local port = %d\n", port.c_str(), sock->getLocalIp().c_str(), sock->getLocalPort());
+    ConnectionManager::getInstance()->adcConnect(*u, static_cast<uint16_t>(Util::toInt(port)), sock->getLocalPort(), BufferedSocket::NAT_CLIENT, token, secure);
 
-       // ... and signal other client to do likewise.
-       send(AdcCommand(AdcCommand::CMD_RNT, u->getIdentity().getSID(), AdcCommand::TYPE_DIRECT).addParam(protocol).
-               addParam(Util::toString(sock->getLocalPort())).addParam(token));
+    // ... and signal other client to do likewise.
+    send(AdcCommand(AdcCommand::CMD_RNT, u->getIdentity().getSID(), AdcCommand::TYPE_DIRECT).addParam(protocol).
+           addParam(Util::toString(sock->getLocalPort())).addParam(token));
 }
 
-void AdcHub::handle(AdcCommand::RNT, AdcCommand& c) throw() {
-       // Sent request for NAT traversal cooperation, which
-       // was acknowledged (with requisite local port information).
-       	if(!BOOLSETTING(ALLOW_NATT))
-            return;
+void AdcHub::handle(AdcCommand::RNT, AdcCommand& c) noexcept {
+    // Sent request for NAT traversal cooperation, which
+    // was acknowledged (with requisite local port information).
+    if(!BOOLSETTING(ALLOW_NATT))
+        return;
 
-       OnlineUser* u = findUser(c.getFrom());
-       if(!u || u->getUser() == ClientManager::getInstance()->getMe() || c.getParameters().size() < 3)
-               return;
+    OnlineUser* u = findUser(c.getFrom());
+    if(!u || u->getUser() == ClientManager::getInstance()->getMe() || c.getParameters().size() < 3)
+        return;
 
-       const string& protocol = c.getParam(0);
-       const string& port = c.getParam(1);
-       const string& token = c.getParam(2);
+    const string& protocol = c.getParam(0);
+    const string& port = c.getParam(1);
+    const string& token = c.getParam(2);
 
-       bool secure = false;
-       if(protocol == CLIENT_PROTOCOL) {
-               // Nothing special
-       } else if(protocol == SECURE_CLIENT_PROTOCOL_TEST && CryptoManager::getInstance()->TLSOk()) {
-               secure = true;
-       } else {
-               unknownProtocol(c.getFrom(), protocol, token);
-               return;
-       }
+    bool secure = false;
+    if(protocol == CLIENT_PROTOCOL) {
+        // Nothing special
+    } else if(protocol == SECURE_CLIENT_PROTOCOL_TEST && CryptoManager::getInstance()->TLSOk()) {
+        secure = true;
+    } else {
+        unknownProtocol(c.getFrom(), protocol, token);
+        return;
+    }
 
-       // Trigger connection attempt sequence locally
-       dcdebug("triggering connecting attempt in RNT: remote port = %s, local IP = %s, local port = %d\n", port.c_str(), sock->getLocalIp().c_str(), sock->getLocalPort());
-       ConnectionManager::getInstance()->adcConnect(*u, static_cast<uint16_t>(Util::toInt(port)), sock->getLocalPort(), BufferedSocket::NAT_SERVER, token, secure);
+    // Trigger connection attempt sequence locally
+    dcdebug("triggering connecting attempt in RNT: remote port = %s, local IP = %s, local port = %d\n", port.c_str(), sock->getLocalIp().c_str(), sock->getLocalPort());
+    ConnectionManager::getInstance()->adcConnect(*u, static_cast<uint16_t>(Util::toInt(port)), sock->getLocalPort(), BufferedSocket::NAT_SERVER, token, secure);
 }
 
 void AdcHub::connect(const OnlineUser& user, const string& token) {
@@ -700,25 +708,25 @@ void AdcHub::privateMessage(const OnlineUser& user, const string& aMessage, bool
 }
 
 void AdcHub::sendUserCmd(const UserCommand& command, const StringMap& params) {
-        if(state != STATE_NORMAL)
-                return;
-        string cmd = Util::formatParams(command.getCommand(), params, false);
-        if(command.isChat()) {
-                if(command.getTo().empty()) {
-                        hubMessage(cmd);
-                } else {
-                        const string& to = command.getTo();
-                        Lock l(cs);
-                        for(SIDMap::const_iterator i = users.begin(); i != users.end(); ++i) {
-                                if(i->second->getIdentity().getNick() == to) {
-                                        privateMessage(*i->second, cmd);
-                                        return;
-                                }
-                        }
-                }
+    if(state != STATE_NORMAL)
+        return;
+    string cmd = Util::formatParams(command.getCommand(), params, false);
+    if(command.isChat()) {
+        if(command.getTo().empty()) {
+            hubMessage(cmd);
         } else {
-                send(cmd);
+            const string& to = command.getTo();
+            Lock l(cs);
+            for(SIDMap::const_iterator i = users.begin(); i != users.end(); ++i) {
+                if(i->second->getIdentity().getNick() == to) {
+                    privateMessage(*i->second, cmd);
+                    return;
+                }
+            }
         }
+    } else {
+        send(cmd);
+    }
 }
 
 const vector<StringList>& AdcHub::getSearchExts() {
@@ -792,9 +800,9 @@ const vector<StringList>& AdcHub::getSearchExts() {
 
 StringList AdcHub::parseSearchExts(int flag) {
     StringList ret;
-    const vector<StringList>& searchExts = getSearchExts();
-    for(std::vector<StringList>::const_iterator i = searchExts.begin(), iend = searchExts.end(); i != iend; ++i) {
-        if(flag & (1 << (i - searchExts.begin()))) {
+    const auto& searchExts = getSearchExts();
+    for(auto i = searchExts.cbegin(), iend = searchExts.cend(); i != iend; ++i) {
+        if(flag & (1 << (i - searchExts.cbegin()))) {
             ret.insert(ret.begin(), i->begin(), i->end());
         }
     }
@@ -826,80 +834,78 @@ void AdcHub::search(int aSizeMode, int64_t aSize, int aFileType, const string& a
             c.addParam("TY", "2");
         }
 
-        if(!aExtList.empty()) {
+        if(aExtList.size() > 2) {
             StringList exts = aExtList;
 
-            if(exts.size() > 2) {
-                sort(exts.begin(), exts.end());
+            sort(exts.begin(), exts.end());
 
-                uint8_t gr = 0;
-                StringList rx;
+            uint8_t gr = 0;
+            StringList rx;
 
-                const vector<StringList>& searchExts = getSearchExts();
-                for(std::vector<StringList>::const_iterator i = searchExts.begin(), iend = searchExts.end(); i != iend; ++i) {
-                    const StringList& def = *i;
+            const auto& searchExts = getSearchExts();
+            for(auto i = searchExts.cbegin(), iend = searchExts.cend(); i != iend; ++i) {
+                const StringList& def = *i;
 
-                    // gather the exts not present in any of the lists
-                    StringList temp(def.size() + exts.size());
-                    temp = StringList(temp.begin(), set_symmetric_difference(def.begin(), def.end(),
-                        exts.begin(), exts.end(), temp.begin()));
+                // gather the exts not present in any of the lists
+                StringList temp(def.size() + exts.size());
+                temp = StringList(temp.begin(), set_symmetric_difference(def.begin(), def.end(),
+                    exts.begin(), exts.end(), temp.begin()));
 
-                    // figure out whether the remaining exts have to be added or removed from the set
-                    StringList rm;
-                    bool ok = true;
-                    for(StringIter diff = temp.begin(); diff != temp.end();) {
-                        if(find(def.begin(), def.end(), *diff) == def.end()) {
-                            ++diff; // will be added further below as an "EX"
-                        } else {
-                            if(rm.size() == 2) {
-                                ok = false;
-                                break;
-                            }
-                            rm.push_back(*diff);
-                            diff = temp.erase(diff);
+                // figure out whether the remaining exts have to be added or removed from the set
+                StringList rx_;
+                bool ok = true;
+                for(auto diff = temp.begin(); diff != temp.end();) {
+                    if(find(def.cbegin(), def.cend(), *diff) == def.cend()) {
+                        ++diff; // will be added further below as an "EX"
+                    } else {
+                        if(rx_.size() == 2) {
+                            ok = false;
+                            break;
                         }
+                        rx_.push_back(*diff);
+                        diff = temp.erase(diff);
                     }
-                    if(!ok) // too many "RX"s necessary - disregard this group
-                        continue;
-
-                    // let's include this group!
-                    gr += 1 << (i - searchExts.begin());
-
-                    exts = temp; // the exts to still add (that were not defined in the group)
-
-                    rx.insert(rx.begin(), rm.begin(), rm.end());
-
-                    if(exts.size() <= 2)
-                        break;
-                    // keep looping to see if there are more exts that can be grouped
                 }
+                if(!ok) // too many "RX"s necessary - disregard this group
+                    continue;
 
-                if(gr) {
-                    // some extensions can be grouped; let's send a command with grouped exts.
-                    AdcCommand c_gr(AdcCommand::CMD_SCH, AdcCommand::TYPE_FEATURE);
-                    c_gr.setFeatures('+' + SEGA_FEATURE);
+                // let's include this group!
+                gr += 1 << (i - searchExts.cbegin());
 
-                    const StringList& params = c.getParameters();
-                    for(StringIterC i = params.begin(), iend = params.end(); i != iend; ++i)
-                        c_gr.addParam(*i);
+                exts = temp; // the exts to still add (that were not defined in the group)
 
-                    for(StringIterC i = exts.begin(), iend = exts.end(); i != iend; ++i)
-                        c_gr.addParam("EX", *i);
-                    c_gr.addParam("GR", Util::toString(gr));
-                    for(StringIterC i = rx.begin(), iend = rx.end(); i != iend; ++i)
-                        c_gr.addParam("RX", *i);
+                rx.insert(rx.begin(), rx_.begin(), rx_.end());
 
-                    sendSearch(c_gr);
-
-                    // make sure users with the feature don't receive the search twice.
-                    c.setType(AdcCommand::TYPE_FEATURE);
-                    c.setFeatures('-' + SEGA_FEATURE);
-                }
+                if(exts.size() <= 2)
+                    break;
+                // keep looping to see if there are more exts that can be grouped
             }
 
-            for(StringIterC i = aExtList.begin(); i != aExtList.end(); ++i)
-                c.addParam("EX", *i);
+            if(gr) {
+                // some extensions can be grouped; let's send a command with grouped exts.
+                AdcCommand c_gr(AdcCommand::CMD_SCH, AdcCommand::TYPE_FEATURE);
+                c_gr.setFeatures('+' + SEGA_FEATURE);
+
+                const auto& params = c.getParameters();
+                for(auto i = params.cbegin(), iend = params.cend(); i != iend; ++i)
+                    c_gr.addParam(*i);
+
+                for(auto i = exts.cbegin(), iend = exts.cend(); i != iend; ++i)
+                    c_gr.addParam("EX", *i);
+                c_gr.addParam("GR", Util::toString(gr));
+                for(auto i = rx.cbegin(), iend = rx.cend(); i != iend; ++i)
+                    c_gr.addParam("RX", *i);
+
+                sendSearch(c_gr);
+
+                // make sure users with the feature don't receive the search twice.
+                c.setType(AdcCommand::TYPE_FEATURE);
+                c.setFeatures('-' + SEGA_FEATURE);
+            }
         }
+
+        for(auto i = aExtList.cbegin(), iend = aExtList.cend(); i != iend; ++i)
+            c.addParam("EX", *i);
     }
 
     sendSearch(c);
@@ -998,7 +1004,7 @@ void AdcHub::info(bool /*alwaysSend*/) {
     string su(SEGA_FEATURE);
     if(CryptoManager::getInstance()->TLSOk()) {
         su += "," + ADCS_FEATURE;
-        const vector<uint8_t> &kp = CryptoManager::getInstance()->getKeyprint();
+        auto &kp = CryptoManager::getInstance()->getKeyprint();
         addParam(lastInfoMap, c, "KP", "SHA256/" + Encoder::toBase32(&kp[0], kp.size()));
     }
 
@@ -1057,17 +1063,21 @@ void AdcHub::send(const AdcCommand& cmd) {
 }
 
 void AdcHub::unknownProtocol(uint32_t target, const string& protocol, const string& token) {
-       AdcCommand cmd(AdcCommand::SEV_FATAL, AdcCommand::ERROR_PROTOCOL_UNSUPPORTED, "Protocol unknown", AdcCommand::TYPE_DIRECT);
-       cmd.setTo(target);
-       cmd.addParam("PR", protocol);
-       cmd.addParam("TO", token);
+    AdcCommand cmd(AdcCommand::SEV_FATAL, AdcCommand::ERROR_PROTOCOL_UNSUPPORTED, "Protocol unknown", AdcCommand::TYPE_DIRECT);
+    cmd.setTo(target);
+    cmd.addParam("PR", protocol);
+    cmd.addParam("TO", token);
 
-       send(cmd);
+    send(cmd);
 }
 
-void AdcHub::on(Connected c) throw() {
+void AdcHub::on(Connected c) noexcept {
     Client::on(c);
 
+    if(state != STATE_PROTOCOL) {
+        return;
+    }
+
     lastInfoMap.clear();
     sid = 0;
     forbiddenCommands.clear();
@@ -1088,7 +1098,7 @@ void AdcHub::on(Connected c) throw() {
     send(cmd);
 }
 
-void AdcHub::on(Line l, const string& aLine) throw() {
+void AdcHub::on(Line l, const string& aLine) noexcept {
     Client::on(l, aLine);
 
     if(!Text::validateUtf8(aLine)) {
@@ -1106,25 +1116,23 @@ void AdcHub::on(Line l, const string& aLine) throw() {
     dispatch(aLine);
 }
 
-void AdcHub::on(Failed f, const string& aLine) throw() {
+void AdcHub::on(Failed f, const string& aLine) noexcept {
     clearUsers();
     Client::on(f, aLine);
 }
 
-void AdcHub::on(Second s, uint64_t aTick) throw() {
+void AdcHub::on(Second s, uint64_t aTick) noexcept {
     Client::on(s, aTick);
     if(state == STATE_NORMAL && (aTick > (getLastActivity() + 120*1000)) ) {
         send("\n", 1);
     }
 }
 #ifdef LUA_SCRIPT
-//aded
 bool AdcScriptInstance::onClientMessage(AdcHub* aClient, const string& aLine) {
-        Lock l(cs);
-        MakeCall("adch", "DataArrival", 1, aClient, aLine);
-        return GetLuaBool();
+    Lock l(cs);
+    MakeCall("adch", "DataArrival", 1, aClient, aLine);
+    return GetLuaBool();
 
 }
-//end
 #endif
 } // namespace dcpp
