@@ -13,11 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "stdinc.h"
-#include "DCPlusPlus.h"
 
 #include "ClientManager.h"
 
@@ -46,8 +45,10 @@ Client* ClientManager::getClient(const string& aHubURL) {
         c = new AdcHub(aHubURL, false);
     } else if(strncmp("adcs://", aHubURL.c_str(), 7) == 0) {
         c = new AdcHub(aHubURL, true);
+    } else if(strncmp("nmdcs://", aHubURL.c_str(), 8) == 0) {
+        c = new NmdcHub(aHubURL, true);
     } else {
-        c = new NmdcHub(aHubURL);
+        c = new NmdcHub(aHubURL, false);
     }
 
     {
@@ -78,15 +79,15 @@ size_t ClientManager::getUserCount() const {
 }
 
 StringList ClientManager::getHubs(const CID& cid, const string& hintUrl) {
-        return getHubs(cid, hintUrl, FavoriteManager::getInstance()->isPrivate(hintUrl));
+    return getHubs(cid, hintUrl, FavoriteManager::getInstance()->isPrivate(hintUrl));
 }
 
 StringList ClientManager::getHubNames(const CID& cid, const string& hintUrl) {
-        return getHubNames(cid, hintUrl, FavoriteManager::getInstance()->isPrivate(hintUrl));
+    return getHubNames(cid, hintUrl, FavoriteManager::getInstance()->isPrivate(hintUrl));
 }
 
 StringList ClientManager::getNicks(const CID& cid, const string& hintUrl) {
-        return getNicks(cid, hintUrl, FavoriteManager::getInstance()->isPrivate(hintUrl));
+    return getNicks(cid, hintUrl, FavoriteManager::getInstance()->isPrivate(hintUrl));
 }
 
 StringList ClientManager::getHubs(const CID& cid, const string& hintUrl, bool priv) {
@@ -147,25 +148,25 @@ StringList ClientManager::getNicks(const CID& cid, const string& hintUrl, bool p
 }
 
 string ClientManager::getField(const CID& cid, const string& hint, const char* field) const {
-        Lock l(cs);
+    Lock l(cs);
 
-        OnlinePairC p;
-        OnlineUser* u = findOnlineUserHint(cid, hint, p);
-        if(u) {
-                string value = u->getIdentity().get(field);
-                if(!value.empty()) {
-                        return value;
-                }
+    OnlinePairC p;
+    OnlineUser* u = findOnlineUserHint(cid, hint, p);
+    if(u) {
+        string value = u->getIdentity().get(field);
+        if(!value.empty()) {
+            return value;
         }
+    }
 
-        for(OnlineIterC i = p.first; i != p.second; ++i) {
-                string value = i->second->getIdentity().get(field);
-                if(!value.empty()) {
-                        return value;
-                }
+    for(OnlineIterC i = p.first; i != p.second; ++i) {
+        string value = i->second->getIdentity().get(field);
+        if(!value.empty()) {
+            return value;
         }
+    }
 
-        return Util::emptyString;
+    return Util::emptyString;
 }
 
 string ClientManager::getConnection(const CID& cid) const {
@@ -247,7 +248,7 @@ string ClientManager::findHubEncoding(const string& aUrl) const {
     return Text::hubDefaultCharset;
 }
 
-UserPtr ClientManager::findLegacyUser(const string& aNick) const throw() {
+UserPtr ClientManager::findLegacyUser(const string& aNick) const noexcept {
     if (aNick.empty())
         return UserPtr();
     Lock l(cs);
@@ -260,7 +261,7 @@ UserPtr ClientManager::findLegacyUser(const string& aNick) const throw() {
     return UserPtr();
 }
 
-UserPtr ClientManager::getUser(const string& aNick, const string& aHubUrl) throw() {
+UserPtr ClientManager::getUser(const string& aNick, const string& aHubUrl) noexcept {
     CID cid = makeCid(aNick, aHubUrl);
     Lock l(cs);
 
@@ -277,7 +278,7 @@ UserPtr ClientManager::getUser(const string& aNick, const string& aHubUrl) throw
     return p;
 }
 
-UserPtr ClientManager::getUser(const CID& cid) throw() {
+UserPtr ClientManager::getUser(const CID& cid) noexcept {
     Lock l(cs);
     UserIter ui = users.find(cid);
     if(ui != users.end()) {
@@ -289,7 +290,7 @@ UserPtr ClientManager::getUser(const CID& cid) throw() {
     return p;
 }
 
-UserPtr ClientManager::findUser(const CID& cid) const throw() {
+UserPtr ClientManager::findUser(const CID& cid) const noexcept {
     Lock l(cs);
     UserMap::const_iterator ui = users.find(cid);
     if(ui != users.end()) {
@@ -309,7 +310,7 @@ bool ClientManager::isOp(const UserPtr& user, const string& aHubUrl) const {
     return false;
 }
 
-CID ClientManager::makeCid(const string& aNick, const string& aHubUrl) const throw() {
+CID ClientManager::makeCid(const string& aNick, const string& aHubUrl) const noexcept {
     string n = Text::toLower(aNick);
     TigerHash th;
     th.update(n.c_str(), n.length());
@@ -319,7 +320,7 @@ CID ClientManager::makeCid(const string& aNick, const string& aHubUrl) const thr
     return CID(th.finalize());
 }
 
-void ClientManager::putOnline(OnlineUser* ou) throw() {
+void ClientManager::putOnline(OnlineUser* ou) noexcept {
     {
         Lock l(cs);
         onlineUsers.insert(make_pair(ou->getUser()->getCID(), ou));
@@ -331,7 +332,7 @@ void ClientManager::putOnline(OnlineUser* ou) throw() {
     }
 }
 
-void ClientManager::putOffline(OnlineUser* ou, bool disconnect) throw() {
+void ClientManager::putOffline(OnlineUser* ou, bool disconnect) noexcept {
     bool lastUser = false;
     {
         Lock l(cs);
@@ -378,19 +379,19 @@ OnlineUser* ClientManager::findOnlineUser(const HintedUser& user, bool priv) {
 }
 
 OnlineUser* ClientManager::findOnlineUser(const CID& cid, const string& hintUrl, bool priv) {
-        OnlinePairC p;
-        OnlineUser* u = findOnlineUserHint(cid, hintUrl, p);
-        if(u) // found an exact match (CID + hint).
-                return u;
+    OnlinePairC p;
+    OnlineUser* u = findOnlineUserHint(cid, hintUrl, p);
+    if(u) // found an exact match (CID + hint).
+        return u;
 
-        if(p.first == p.second) // no user found with the given CID.
-                return 0;
+    if(p.first == p.second) // no user found with the given CID.
+        return 0;
 
-        // if the hint hub is private, don't allow connecting to the same user from another hub.
-        if(priv)
-                return 0;
+    // if the hint hub is private, don't allow connecting to the same user from another hub.
+    if(priv)
+        return 0;
 
-        // ok, hub not private, return a random user that matches the given CID but not the hint.
+    // ok, hub not private, return a random user that matches the given CID but not the hint.
     return p.first->second;
 }
 
@@ -401,7 +402,7 @@ void ClientManager::connect(const HintedUser& user, const string& token) {
     OnlineUser* u = findOnlineUser(user, priv);
 
     if(u) {
-            u->getClient().connect(*u, token);
+        u->getClient().connect(*u, token);
     }
 }
 
@@ -417,21 +418,25 @@ void ClientManager::privateMessage(const HintedUser& user, const string& msg, bo
 }
 
 void ClientManager::userCommand(const HintedUser& user, const UserCommand& uc, StringMap& params, bool compatibility) {
-        Lock l(cs);
-        /** @todo we allow wrong hints for now ("false" param of findOnlineUser) because users
-         * extracted from search results don't always have a correct hint; see
-         * SearchManager::onRES(const AdcCommand& cmd, ...). when that is done, and SearchResults are
-         * switched to storing only reliable HintedUsers (found with the token of the ADC command),
-         * change this call to findOnlineUserHint. */
-        OnlineUser* ou = findOnlineUser(user.user->getCID(), user.hint.empty() ? uc.getHub() : user.hint, false);
-        if(!ou || ou->getClientBase().type == ClientBase::DHT)
-                return;
+    Lock l(cs);
+    /** @todo we allow wrong hints for now ("false" param of findOnlineUser) because users
+     * extracted from search results don't always have a correct hint; see
+     * SearchManager::onRES(const AdcCommand& cmd, ...). when that is done, and SearchResults are
+     * switched to storing only reliable HintedUsers (found with the token of the ADC command),
+     * change this call to findOnlineUserHint. */
+    OnlineUser* ou = findOnlineUser(user.user->getCID(), user.hint.empty() ? uc.getHub() : user.hint, false);
+    if(!ou
+#ifdef WITH_DHT
+       || ou->getClientBase().type == ClientBase::DHT
+#endif
+                                                             )
+        return;
 
-        ou->getIdentity().getParams(params, "user", compatibility);
-        ou->getClient().getHubIdentity().getParams(params, "hub", false);
-        ou->getClient().getMyIdentity().getParams(params, "my", compatibility);
-        ou->getClient().escapeParams(params);
-        ou->getClient().sendUserCmd(uc, params);
+    ou->getIdentity().getParams(params, "user", compatibility);
+    ou->getClient().getHubIdentity().getParams(params, "hub", false);
+    ou->getClient().getMyIdentity().getParams(params, "my", compatibility);
+    ou->getClient().escapeParams(params);
+    ou->getClient().sendUserCmd(uc, params);
 }
 
 void ClientManager::send(AdcCommand& cmd, const CID& cid) {
@@ -440,7 +445,11 @@ void ClientManager::send(AdcCommand& cmd, const CID& cid) {
     if(i != onlineUsers.end()) {
         OnlineUser& u = *i->second;
         if(cmd.getType() == AdcCommand::TYPE_UDP && !u.getIdentity().isUdpActive()) {
-            if(u.getUser()->isNMDC() || u.getClientBase().getType() == Client::DHT)
+            if(u.getUser()->isNMDC()
+#ifdef WITH_DHT
+                || u.getClientBase().getType() == Client::DHT
+#endif
+                                                              )
                 return;
             cmd.setType(AdcCommand::TYPE_DIRECT);
             cmd.setTo(u.getIdentity().getSID());
@@ -465,7 +474,7 @@ void ClientManager::infoUpdated() {
 }
 
 void ClientManager::on(NmdcSearch, Client* aClient, const string& aSeeker, int aSearchType, int64_t aSize,
-                                    int aFileType, const string& aString) throw()
+                                    int aFileType, const string& aString) noexcept
 {
     Speaker<ClientManagerListener>::fire(ClientManagerListener::IncomingSearch(), aString);
 
@@ -538,7 +547,7 @@ void ClientManager::on(NmdcSearch, Client* aClient, const string& aSeeker, int a
     }
 }
 
-void ClientManager::on(AdcSearch, Client* c, const AdcCommand& adc, const CID& from) throw() {
+void ClientManager::on(AdcSearch, Client* c, const AdcCommand& adc, const CID& from) noexcept {
     bool isUdpActive = false;
     {
         Lock l(cs);
@@ -587,7 +596,7 @@ uint64_t ClientManager::search(StringList& who, int aSizeMode, int64_t aSize, in
     return estimateSearchSpan;
 }
 
-void ClientManager::on(TimerManagerListener::Minute, uint64_t /* aTick */) throw() {
+void ClientManager::on(TimerManagerListener::Minute, uint64_t /* aTick */) noexcept {
     Lock l(cs);
 
     // Collect some garbage...
@@ -628,101 +637,101 @@ CID ClientManager::getMyCID() {
     return CID(tiger.finalize());
 }
 
-void ClientManager::updateNick(const OnlineUser& user) throw() {
-        if(!user.getIdentity().getNick().empty()) {
-    Lock l(cs);
-                NickMap::iterator i = nicks.find(user.getUser()->getCID());
-                if(i == nicks.end()) {
-                        nicks[user.getUser()->getCID()] = std::make_pair(user.getIdentity().getNick(), false);
-                } else {
-                        i->second.first = user.getIdentity().getNick();
-                }
+void ClientManager::updateNick(const OnlineUser& user) noexcept {
+    if(!user.getIdentity().getNick().empty()) {
+        Lock l(cs);
+        NickMap::iterator i = nicks.find(user.getUser()->getCID());
+        if(i == nicks.end()) {
+                nicks[user.getUser()->getCID()] = std::make_pair(user.getIdentity().getNick(), false);
+        } else {
+                i->second.first = user.getIdentity().getNick();
         }
     }
+}
 
 void ClientManager::loadUsers() {
-        try {
-                SimpleXML xml;
-                xml.fromXML(File(getUsersFile(), File::READ, File::OPEN).read());
+    try {
+        SimpleXML xml;
+        xml.fromXML(File(getUsersFile(), File::READ, File::OPEN).read());
 
-                if(xml.findChild("Users")) {
-                        xml.stepIn();
+        if(xml.findChild("Users")) {
+            xml.stepIn();
 
-                        {
-                                Lock l(cs);
-                                while(xml.findChild("User")) {
-                                        nicks[CID(xml.getChildAttrib("CID"))] = std::make_pair(xml.getChildAttrib("Nick"), false);
-                                }
-                        }
-
-                        xml.stepOut();
+            {
+                Lock l(cs);
+                while(xml.findChild("User")) {
+                    nicks[CID(xml.getChildAttrib("CID"))] = std::make_pair(xml.getChildAttrib("Nick"), false);
                 }
-        } catch(const Exception&) { }
-    }
+            }
+
+            xml.stepOut();
+        }
+    } catch(const Exception&) { }
+}
 
 void ClientManager::saveUsers() const {
-        try {
-                SimpleXML xml;
-                xml.addTag("Users");
-                xml.stepIn();
+    try {
+        SimpleXML xml;
+        xml.addTag("Users");
+        xml.stepIn();
 
-                {
-                        Lock l(cs);
-                        for(NickMap::const_iterator i = nicks.begin(), iend = nicks.end(); i != iend; ++i) {
-                                if(i->second.second) {
-                                        xml.addTag("User");
-                                        xml.addChildAttrib("CID", i->first.toBase32());
-                                        xml.addChildAttrib("Nick", i->second.first);
-                                }
-                        }
+        {
+            Lock l(cs);
+            for(NickMap::const_iterator i = nicks.begin(), iend = nicks.end(); i != iend; ++i) {
+                if(i->second.second) {
+                    xml.addTag("User");
+                    xml.addChildAttrib("CID", i->first.toBase32());
+                    xml.addChildAttrib("Nick", i->second.first);
                 }
+            }
+        }
 
-                xml.stepOut();
+        xml.stepOut();
 
-                const string fName = getUsersFile();
-                File out(fName + ".tmp", File::WRITE, File::CREATE | File::TRUNCATE);
-                BufferedOutputStream<false> f(&out);
-                f.write(SimpleXML::utf8Header);
-                xml.toXML(&f);
-                f.flush();
-                out.close();
-                File::deleteFile(fName);
-                File::renameFile(fName + ".tmp", fName);
-        } catch(const Exception&) { }
+        const string fName = getUsersFile();
+        File out(fName + ".tmp", File::WRITE, File::CREATE | File::TRUNCATE);
+        BufferedOutputStream<false> f(&out);
+        f.write(SimpleXML::utf8Header);
+        xml.toXML(&f);
+        f.flush();
+        out.close();
+        File::deleteFile(fName);
+        File::renameFile(fName + ".tmp", fName);
+    } catch(const Exception&) { }
 }
 
 void ClientManager::saveUser(const CID& cid) {
-        Lock l(cs);
-        NickMap::iterator i = nicks.find(cid);
-        if(i != nicks.end())
-                i->second.second = true;
+    Lock l(cs);
+    NickMap::iterator i = nicks.find(cid);
+    if(i != nicks.end())
+        i->second.second = true;
 }
 
-void ClientManager::on(Connected, Client* c) throw() {
+void ClientManager::on(Connected, Client* c) noexcept {
     fire(ClientManagerListener::ClientConnected(), c);
 }
 
-void ClientManager::on(UserUpdated, Client*, const OnlineUser& user) throw() {
+void ClientManager::on(UserUpdated, Client*, const OnlineUser& user) noexcept {
     updateNick(user);
     fire(ClientManagerListener::UserUpdated(), user);
 }
 
-void ClientManager::on(UsersUpdated, Client* c, const OnlineUserList& l) throw() {
+void ClientManager::on(UsersUpdated, Client* c, const OnlineUserList& l) noexcept {
     for(OnlineUserList::const_iterator i = l.begin(), iend = l.end(); i != iend; ++i) {
         updateNick(*(*i));
         fire(ClientManagerListener::UserUpdated(), *(*i));
     }
 }
 
-void ClientManager::on(HubUpdated, Client* c) throw() {
+void ClientManager::on(HubUpdated, Client* c) noexcept {
     fire(ClientManagerListener::ClientUpdated(), c);
 }
 
-void ClientManager::on(Failed, Client* client, const string&) throw() {
+void ClientManager::on(Failed, Client* client, const string&) noexcept {
     fire(ClientManagerListener::ClientDisconnected(), client);
 }
 
-void ClientManager::on(HubUserCommand, Client* client, int aType, int ctx, const string& name, const string& command) throw() {
+void ClientManager::on(HubUserCommand, Client* client, int aType, int ctx, const string& name, const string& command) noexcept {
     if(BOOLSETTING(HUB_USER_COMMANDS)) {
         if(aType == UserCommand::TYPE_REMOVE) {
             int cmd = FavoriteManager::getInstance()->findUserCommand(name, client->getHubUrl());
@@ -737,26 +746,26 @@ void ClientManager::on(HubUserCommand, Client* client, int aType, int ctx, const
 }
 int ClientManager::getMode(const string& aHubUrl) const {
 
-        if(aHubUrl.empty())
-                return SETTING(INCOMING_CONNECTIONS);
+    if(aHubUrl.empty())
+        return SETTING(INCOMING_CONNECTIONS);
 
-        int mode = 0;
-        const FavoriteHubEntry* hub = FavoriteManager::getInstance()->getFavoriteHubEntry(aHubUrl);
-        if(hub) {
-            switch(hub->getMode()) {
-                    case 1 :
-                            mode = SettingsManager::INCOMING_DIRECT;
-                            break;
-                    case 2 :
-                            mode = SettingsManager::INCOMING_FIREWALL_PASSIVE;
-                            break;
-                    default:
-                            mode = SETTING(INCOMING_CONNECTIONS);
-            }
-        } else {
+    int mode = 0;
+    const FavoriteHubEntry* hub = FavoriteManager::getInstance()->getFavoriteHubEntry(aHubUrl);
+    if(hub) {
+        switch(hub->getMode()) {
+            case 1 :
+                mode = SettingsManager::INCOMING_DIRECT;
+                break;
+            case 2 :
+                mode = SettingsManager::INCOMING_FIREWALL_PASSIVE;
+                break;
+            default:
                 mode = SETTING(INCOMING_CONNECTIONS);
         }
-        return mode;
+    } else {
+        mode = SETTING(INCOMING_CONNECTIONS);
+    }
+    return mode;
 }
 
 void ClientManager::cancelSearch(void* aOwner) {
@@ -767,61 +776,62 @@ void ClientManager::cancelSearch(void* aOwner) {
     }
 }
 
-OnlineUserPtr ClientManager::findDHTNode(const CID& cid) const
-{
-        Lock l(cs);
+#ifdef WITH_DHT
+OnlineUserPtr ClientManager::findDHTNode(const CID& cid) const {
+    Lock l(cs);
 
-        OnlinePairC op = onlineUsers.equal_range(cid);
-        for(OnlineIterC i = op.first; i != op.second; ++i) {
-                OnlineUser* ou = i->second;
+    OnlinePairC op = onlineUsers.equal_range(cid);
+    for(OnlineIterC i = op.first; i != op.second; ++i) {
+        OnlineUser* ou = i->second;
 
-                // user not in DHT, so don't bother with other hubs
-                if(!ou->getUser()->isSet(User::DHT))
-                        break;
+        // user not in DHT, so don't bother with other hubs
+        if(!ou->getUser()->isSet(User::DHT))
+            break;
 
-                if(ou->getClientBase().getType() == Client::DHT)
-                        return ou;
-        }
+        if(ou->getClientBase().getType() == Client::DHT)
+            return ou;
+    }
 
-        return NULL;
+    return NULL;
 }
+#endif
 
 #ifdef LUA_SCRIPT
-bool ClientManager::ucExecuteLua(const string& ucCommand, StringMap& params) throw() {
-        bool executedlua = false;
-        string::size_type i, j, k;
-        i = j = k = 0;
-        string tmp = ucCommand;
-        while( (i = tmp.find("%[lua:", i)) != string::npos) {
-                i += 6;
-                j = tmp.find(']', i);
-                if(j == string::npos)
-                        break;
-                string chunk = tmp.substr(i, j-i);
-                // for making possible using %[nick] and similar parameters too
-                // !%!{nick!}
-                k = 0;
-                while( (k = chunk.find("!%")) != string::npos) {
-                        chunk.erase(k, 2);
-                        chunk.insert(k, "%");
-                }
-                k = 0;
-                while( (k = chunk.find("!{")) != string::npos) {
-                        chunk.erase(k, 2);
-                        chunk.insert(k, "[");
-                }
-                k = 0;
-                while( (k = chunk.find("!}")) != string::npos) {
-                        chunk.erase(k, 2);
-                        chunk.insert(k, "]");
-                }
-                //@todo: use filter? I opted for no here, but this means Lua has to be careful about
-                //filtering if it cares.
-                ScriptManager::getInstance()->EvaluateChunk(Util::formatParams(chunk, params, false));
-                executedlua = true;
-                i = j + 1;
+bool ClientManager::ucExecuteLua(const string& ucCommand, StringMap& params) noexcept {
+    bool executedlua = false;
+    string::size_type i, j, k;
+    i = j = k = 0;
+    string tmp = ucCommand;
+    while( (i = tmp.find("%[lua:", i)) != string::npos) {
+        i += 6;
+        j = tmp.find(']', i);
+        if(j == string::npos)
+            break;
+        string chunk = tmp.substr(i, j-i);
+        // for making possible using %[nick] and similar parameters too
+        // !%!{nick!}
+        k = 0;
+        while( (k = chunk.find("!%")) != string::npos) {
+            chunk.erase(k, 2);
+            chunk.insert(k, "%");
         }
-        return executedlua;
+        k = 0;
+        while( (k = chunk.find("!{")) != string::npos) {
+            chunk.erase(k, 2);
+            chunk.insert(k, "[");
+        }
+        k = 0;
+        while( (k = chunk.find("!}")) != string::npos) {
+            chunk.erase(k, 2);
+            chunk.insert(k, "]");
+        }
+        //@todo: use filter? I opted for no here, but this means Lua has to be careful about
+        //filtering if it cares.
+        ScriptManager::getInstance()->EvaluateChunk(Util::formatParams(chunk, params, false));
+        executedlua = true;
+        i = j + 1;
+    }
+    return executedlua;
 }
 #endif // LUA_SCRIPT
 } // namespace dcpp
