@@ -13,11 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "stdinc.h"
-#include "DCPlusPlus.h"
 
 #include "ConnectionManager.h"
 
@@ -47,7 +46,7 @@ ConnectionManager::ConnectionManager() : floodCounter(0), server(0), secureServe
     adcFeatures.push_back("AD" + UserConnection::FEATURE_ADC_BZIP);
 }
 
-void ConnectionManager::listen() throw(SocketException){
+void ConnectionManager::listen() {
     disconnect();
 
     server = new Server(false, static_cast<uint16_t>(SETTING(TCP_PORT)), SETTING(BIND_ADDRESS));
@@ -67,25 +66,25 @@ void ConnectionManager::listen() throw(SocketException){
  * @param aUser The user to connect to.
  */
 void ConnectionManager::getDownloadConnection(const HintedUser& aUser) {
-        dcassert((bool)aUser.user);
+    dcassert((bool)aUser.user);
     {
         Lock l(cs);
-                ConnectionQueueItem::Iter i = find(downloads.begin(), downloads.end(), aUser.user);
+        ConnectionQueueItem::Iter i = find(downloads.begin(), downloads.end(), aUser.user);
         if(i == downloads.end()) {
-                        getCQI(aUser, true);
+            getCQI(aUser, true);
         } else {
-                        DownloadManager::getInstance()->checkIdle(aUser.user);
+            DownloadManager::getInstance()->checkIdle(aUser.user);
         }
     }
 }
 
 ConnectionQueueItem* ConnectionManager::getCQI(const HintedUser& aUser, bool download) {
-        ConnectionQueueItem* cqi = new ConnectionQueueItem(aUser, download);
+    ConnectionQueueItem* cqi = new ConnectionQueueItem(aUser, download);
     if(download) {
-                dcassert(find(downloads.begin(), downloads.end(), aUser.user) == downloads.end());
+        dcassert(find(downloads.begin(), downloads.end(), aUser.user) == downloads.end());
         downloads.push_back(cqi);
     } else {
-                dcassert(find(uploads.begin(), uploads.end(), aUser.user) == uploads.end());
+        dcassert(find(uploads.begin(), uploads.end(), aUser.user) == uploads.end());
         uploads.push_back(cqi);
     }
 
@@ -105,7 +104,7 @@ void ConnectionManager::putCQI(ConnectionQueueItem* cqi) {
     delete cqi;
 }
 
-UserConnection* ConnectionManager::getConnection(bool aNmdc, bool secure) throw() {
+UserConnection* ConnectionManager::getConnection(bool aNmdc, bool secure) noexcept {
     UserConnection* uc = new UserConnection(secure);
     uc->addListener(this);
     {
@@ -125,7 +124,7 @@ void ConnectionManager::putConnection(UserConnection* aConn) {
     userConnections.erase(remove(userConnections.begin(), userConnections.end(), aConn), userConnections.end());
 }
 
-void ConnectionManager::on(TimerManagerListener::Second, uint64_t aTick) throw() {
+void ConnectionManager::on(TimerManagerListener::Second, uint64_t aTick) noexcept {
     UserList passiveUsers;
     ConnectionQueueItem::List removed;
 
@@ -138,26 +137,26 @@ void ConnectionManager::on(TimerManagerListener::Second, uint64_t aTick) throw()
             ConnectionQueueItem* cqi = *i;
 
             if(cqi->getState() != ConnectionQueueItem::ACTIVE) {
-                                if(!cqi->getUser().user->isOnline()) {
+                if(!cqi->getUser().user->isOnline()) {
                     // Not online anymore...remove it from the pending...
                     removed.push_back(cqi);
                     continue;
                 }
 
-                                if(cqi->getUser().user->isSet(User::PASSIVE) && !ClientManager::getInstance()->isActive()) {
+                if(cqi->getUser().user->isSet(User::PASSIVE) && !ClientManager::getInstance()->isActive()) {
                     passiveUsers.push_back(cqi->getUser());
                     removed.push_back(cqi);
                     continue;
                 }
 
-                                if(cqi->getErrors() == -1 && cqi->getLastAttempt() != 0) {
-                                        // protocol error, don't reconnect except after a forced attempt
-                                        continue;
-                                }
+                if(cqi->getErrors() == -1 && cqi->getLastAttempt() != 0) {
+                        // protocol error, don't reconnect except after a forced attempt
+                        continue;
+                }
 
-                                if(cqi->getLastAttempt() == 0 || (!attemptDone &&
-                                        cqi->getLastAttempt() + 60 * 1000 * max(1, cqi->getErrors()) < aTick))
-                                {
+                if(cqi->getLastAttempt() == 0 || (!attemptDone &&
+                    cqi->getLastAttempt() + 60 * 1000 * max(1, cqi->getErrors()) < aTick))
+                {
                     cqi->setLastAttempt(aTick);
 
                     QueueItem::Priority prio = QueueManager::getInstance()->hasDownload(cqi->getUser());
@@ -172,7 +171,7 @@ void ConnectionManager::on(TimerManagerListener::Second, uint64_t aTick) throw()
                     if(cqi->getState() == ConnectionQueueItem::WAITING) {
                         if(startDown) {
                             cqi->setState(ConnectionQueueItem::CONNECTING);
-                                                        ClientManager::getInstance()->connect(cqi->getUser(), cqi->getToken());
+                            ClientManager::getInstance()->connect(cqi->getUser(), cqi->getToken());
                             fire(ConnectionManagerListener::StatusChanged(), cqi);
                             attemptDone = true;
                         } else {
@@ -182,8 +181,8 @@ void ConnectionManager::on(TimerManagerListener::Second, uint64_t aTick) throw()
                     } else if(cqi->getState() == ConnectionQueueItem::NO_DOWNLOAD_SLOTS && startDown) {
                         cqi->setState(ConnectionQueueItem::WAITING);
                     }
-                                } else if(cqi->getState() == ConnectionQueueItem::CONNECTING && cqi->getLastAttempt() + 50 * 1000 < aTick) {
-                                        cqi->setErrors(cqi->getErrors() + 1);
+                } else if(cqi->getState() == ConnectionQueueItem::CONNECTING && cqi->getLastAttempt() + 50 * 1000 < aTick) {
+                    cqi->setErrors(cqi->getErrors() + 1);
                     fire(ConnectionManagerListener::Failed(), cqi, _("Connection timeout"));
                     cqi->setState(ConnectionQueueItem::WAITING);
                 }
@@ -201,11 +200,11 @@ void ConnectionManager::on(TimerManagerListener::Second, uint64_t aTick) throw()
     }
 }
 
-void ConnectionManager::on(TimerManagerListener::Minute, uint64_t aTick) throw() {
+void ConnectionManager::on(TimerManagerListener::Minute, uint64_t aTick) noexcept {
     Lock l(cs);
 
     for(UserConnectionList::iterator j = userConnections.begin(); j != userConnections.end(); ++j) {
-                if(((*j)->getLastActivity() + 180*1000) < aTick) {
+        if(((*j)->getLastActivity() + 180*1000) < aTick) {
             (*j)->disconnect(true);
         }
     }
@@ -226,7 +225,7 @@ ConnectionManager::Server::Server(bool secure_, uint16_t aPort, const string& ip
 
 static const uint32_t POLL_TIMEOUT = 250;
 
-int ConnectionManager::Server::run() throw() {
+int ConnectionManager::Server::run() noexcept {
     while(!die) {
         try {
             while(!die) {
@@ -272,7 +271,7 @@ int ConnectionManager::Server::run() throw() {
  * Someone's connecting, accept the connection and wait for identification...
  * It's always the other fellow that starts sending if he made the connection.
  */
-void ConnectionManager::accept(const Socket& sock, bool secure) throw() {
+void ConnectionManager::accept(const Socket& sock, bool secure) noexcept {
     uint64_t now = GET_TICK();
 
     if(now > floodCounter) {
@@ -302,19 +301,22 @@ void ConnectionManager::accept(const Socket& sock, bool secure) throw() {
         delete uc;
     }
 }
+void ConnectionManager::nmdcConnect(const string& aServer, uint16_t aPort, const string& aNick, const string& hubUrl, const string& encoding, bool secure) {
+    nmdcConnect(aServer, aPort, 0, BufferedSocket::NAT_NONE, aNick, hubUrl, encoding, secure);
+}
 
-void ConnectionManager::nmdcConnect(const string& aServer, uint16_t aPort, const string& aNick, const string& hubUrl, const string& encoding) {
+void ConnectionManager::nmdcConnect(const string& aServer, uint16_t aPort, uint16_t localPort, BufferedSocket::NatRoles natRole, const string& aNick, const string& hubUrl, const string& encoding, bool secure) {
     if(shuttingDown)
         return;
 
-    UserConnection* uc = getConnection(true, false);
+    UserConnection* uc = getConnection(true, secure);
     uc->setToken(aNick);
     uc->setHubUrl(hubUrl);
     uc->setEncoding(encoding);
     uc->setState(UserConnection::STATE_CONNECT);
     uc->setFlag(UserConnection::FLAG_NMDC);
     try {
-                uc->connect(aServer, aPort, 0, BufferedSocket::NAT_NONE);
+        uc->connect(aServer, aPort, localPort, natRole);
     } catch(const Exception&) {
         putConnection(uc);
         delete uc;
@@ -333,26 +335,30 @@ void ConnectionManager::adcConnect(const OnlineUser& aUser, uint16_t aPort, uint
     uc->setToken(aToken);
     uc->setEncoding(Text::utf8);
     uc->setState(UserConnection::STATE_CONNECT);
+#ifdef WITH_DHT
     uc->setHubUrl(&aUser.getClient() == NULL ? "DHT" : aUser.getClient().getHubUrl());
+#else
+    uc->setHubUrl(aUser.getClient().getHubUrl());
+#endif
     if(aUser.getIdentity().isOp()) {
         uc->setFlag(UserConnection::FLAG_OP);
     }
     try {
-                uc->connect(aUser.getIdentity().getIp(), aPort, localPort, natRole);
+        uc->connect(aUser.getIdentity().getIp(), aPort, localPort, natRole);
     } catch(const Exception&) {
         putConnection(uc);
         delete uc;
     }
 }
 
-void ConnectionManager::disconnect() throw() {
+void ConnectionManager::disconnect() noexcept {
     delete server;
     delete secureServer;
 
     server = secureServer = 0;
 }
 
-void ConnectionManager::on(AdcCommand::SUP, UserConnection* aSource, const AdcCommand& cmd) throw() {
+void ConnectionManager::on(AdcCommand::SUP, UserConnection* aSource, const AdcCommand& cmd) noexcept {
     if(aSource->getState() != UserConnection::STATE_SUPNICK) {
         // Already got this once, ignore...@todo fix support updates
         dcdebug("CM::onSUP %p sent sup twice\n", (void*)aSource);
@@ -407,11 +413,11 @@ void ConnectionManager::on(AdcCommand::SUP, UserConnection* aSource, const AdcCo
     aSource->setState(UserConnection::STATE_INF);
 }
 
-void ConnectionManager::on(AdcCommand::STA, UserConnection*, const AdcCommand& cmd) throw() {
+void ConnectionManager::on(AdcCommand::STA, UserConnection*, const AdcCommand& cmd) noexcept {
 
 }
 
-void ConnectionManager::on(UserConnectionListener::Connected, UserConnection* aSource) throw() {
+void ConnectionManager::on(UserConnectionListener::Connected, UserConnection* aSource) noexcept {
     if(aSource->isSecure() && !aSource->isTrusted() && !BOOLSETTING(ALLOW_UNTRUSTED_CLIENTS)) {
         putConnection(aSource);
         QueueManager::getInstance()->removeSource(aSource->getUser(), QueueItem::Source::FLAG_UNTRUSTED);
@@ -433,7 +439,7 @@ void ConnectionManager::on(UserConnectionListener::Connected, UserConnection* aS
     aSource->setState(UserConnection::STATE_SUPNICK);
 }
 
-void ConnectionManager::on(UserConnectionListener::MyNick, UserConnection* aSource, const string& aNick) throw() {
+void ConnectionManager::on(UserConnectionListener::MyNick, UserConnection* aSource, const string& aNick) noexcept {
     if(aSource->getState() != UserConnection::STATE_SUPNICK) {
         // Already got this once, ignore...
         dcdebug("CM::onMyNick %p sent nick twice\n", (void*)aSource);
@@ -466,10 +472,10 @@ void ConnectionManager::on(UserConnectionListener::MyNick, UserConnection* aSour
         Lock l(cs);
         for(ConnectionQueueItem::Iter i = downloads.begin(); i != downloads.end(); ++i) {
             ConnectionQueueItem* cqi = *i;
-                        cqi->setErrors(0);
-                        if((cqi->getState() == ConnectionQueueItem::CONNECTING || cqi->getState() == ConnectionQueueItem::WAITING) &&
-                                cqi->getUser().user->getCID() == cid)
-                        {
+            cqi->setErrors(0);
+            if((cqi->getState() == ConnectionQueueItem::CONNECTING || cqi->getState() == ConnectionQueueItem::WAITING) &&
+                    cqi->getUser().user->getCID() == cid)
+            {
                 aSource->setUser(cqi->getUser());
                 // Indicate that we're interested in this file...
                 aSource->setFlag(UserConnection::FLAG_DOWNLOAD);
@@ -504,7 +510,7 @@ void ConnectionManager::on(UserConnectionListener::MyNick, UserConnection* aSour
     aSource->setState(UserConnection::STATE_LOCK);
 }
 
-void ConnectionManager::on(UserConnectionListener::CLock, UserConnection* aSource, const string& aLock, const string& aPk) throw() {
+void ConnectionManager::on(UserConnectionListener::CLock, UserConnection* aSource, const string& aLock, const string& aPk) noexcept {
     if(aSource->getState() != UserConnection::STATE_LOCK) {
         dcdebug("CM::onLock %p received lock twice, ignoring\n", (void*)aSource);
         return;
@@ -524,7 +530,7 @@ void ConnectionManager::on(UserConnectionListener::CLock, UserConnection* aSourc
     aSource->key(CryptoManager::getInstance()->makeKey(aLock));
 }
 
-void ConnectionManager::on(UserConnectionListener::Direction, UserConnection* aSource, const string& dir, const string& num) throw() {
+void ConnectionManager::on(UserConnectionListener::Direction, UserConnection* aSource, const string& dir, const string& num) noexcept {
     if(aSource->getState() != UserConnection::STATE_DIRECTION) {
         dcdebug("CM::onDirection %p received direction twice, ignoring\n", (void*)aSource);
         return;
@@ -595,7 +601,7 @@ void ConnectionManager::addUploadConnection(UserConnection* uc) {
 
         ConnectionQueueItem::Iter i = find(uploads.begin(), uploads.end(), uc->getUser());
         if(i == uploads.end()) {
-                        ConnectionQueueItem* cqi = getCQI(uc->getHintedUser(), false);
+            ConnectionQueueItem* cqi = getCQI(uc->getHintedUser(), false);
 
             cqi->setState(ConnectionQueueItem::ACTIVE);
             uc->setFlag(UserConnection::FLAG_ASSOCIATED);
@@ -614,7 +620,7 @@ void ConnectionManager::addUploadConnection(UserConnection* uc) {
     }
 }
 
-void ConnectionManager::on(UserConnectionListener::Key, UserConnection* aSource, const string&/* aKey*/) throw() {
+void ConnectionManager::on(UserConnectionListener::Key, UserConnection* aSource, const string&/* aKey*/) noexcept {
     if(aSource->getState() != UserConnection::STATE_KEY) {
         dcdebug("CM::onKey Bad state, ignoring");
         return;
@@ -629,7 +635,7 @@ void ConnectionManager::on(UserConnectionListener::Key, UserConnection* aSource,
     }
 }
 
-void ConnectionManager::on(AdcCommand::INF, UserConnection* aSource, const AdcCommand& cmd) throw() {
+void ConnectionManager::on(AdcCommand::INF, UserConnection* aSource, const AdcCommand& cmd) noexcept {
     if(aSource->getState() != UserConnection::STATE_INF) {
         aSource->send(AdcCommand(AdcCommand::SEV_FATAL, AdcCommand::ERROR_PROTOCOL_GENERIC, "Expecting INF"));
         aSource->disconnect();
@@ -675,7 +681,7 @@ void ConnectionManager::on(AdcCommand::INF, UserConnection* aSource, const AdcCo
         ConnectionQueueItem::Iter i = find(downloads.begin(), downloads.end(), aSource->getUser());
 
         if(i != downloads.end()) {
-                        (*i)->setErrors(0);
+            (*i)->setErrors(0);
 
             const string& to = (*i)->getToken();
 
@@ -707,34 +713,34 @@ void ConnectionManager::force(const UserPtr& aUser) {
 }
 
 bool ConnectionManager::checkKeyprint(UserConnection *aSource) {
-        dcassert(aSource->getUser());
-
-        vector<uint8_t> kp = aSource->getKeyprint();
-        if(kp.empty()) {
-                return true;
-        }
-
-        string kp2 = ClientManager::getInstance()->getField(aSource->getUser()->getCID(), aSource->getHubUrl(), "KP");
-        if(kp2.empty()) {
-                // TODO false probably
-                return true;
-        }
-
-        if(kp2.compare(0, 7, "SHA256/") != 0) {
-                // Unsupported hash
-                return true;
-        }
-
-        dcdebug("Keyprint: %s vs %s\n", Encoder::toBase32(&kp[0], kp.size()).c_str(), kp2.c_str() + 7);
-
-        vector<uint8_t> kp2v(kp.size());
-        Encoder::fromBase32(&kp2[7], &kp2v[0], kp2v.size());
-        if(!std::equal(kp.begin(), kp.end(), kp2v.begin())) {
-                dcdebug("Not equal...\n");
-                return false;
-        }
+    dcassert(aSource->getUser());
 
+    vector<uint8_t> kp = aSource->getKeyprint();
+    if(kp.empty()) {
         return true;
+    }
+
+    string kp2 = ClientManager::getInstance()->getField(aSource->getUser()->getCID(), aSource->getHubUrl(), "KP");
+    if(kp2.empty()) {
+        // TODO false probably
+        return true;
+    }
+
+    if(kp2.compare(0, 7, "SHA256/") != 0) {
+        // Unsupported hash
+        return true;
+    }
+
+    dcdebug("Keyprint: %s vs %s\n", Encoder::toBase32(&kp[0], kp.size()).c_str(), kp2.c_str() + 7);
+
+    vector<uint8_t> kp2v(kp.size());
+    Encoder::fromBase32(&kp2[7], &kp2v[0], kp2v.size());
+    if(!std::equal(kp.begin(), kp.end(), kp2v.begin())) {
+        dcdebug("Not equal...\n");
+        return false;
+    }
+
+    return true;
 }
 
 void ConnectionManager::failed(UserConnection* aSource, const string& aError, bool protocolError) {
@@ -747,7 +753,7 @@ void ConnectionManager::failed(UserConnection* aSource, const string& aError, bo
             ConnectionQueueItem* cqi = *i;
             cqi->setState(ConnectionQueueItem::WAITING);
             cqi->setLastAttempt(GET_TICK());
-                        cqi->setErrors(protocolError ? -1 : (cqi->getErrors() + 1));
+            cqi->setErrors(protocolError ? -1 : (cqi->getErrors() + 1));
             fire(ConnectionManagerListener::Failed(), cqi, aError);
         } else if(aSource->isSet(UserConnection::FLAG_UPLOAD)) {
             ConnectionQueueItem::Iter i = find(uploads.begin(), uploads.end(), aSource->getUser());
@@ -759,12 +765,12 @@ void ConnectionManager::failed(UserConnection* aSource, const string& aError, bo
     putConnection(aSource);
 }
 
-void ConnectionManager::on(UserConnectionListener::Failed, UserConnection* aSource, const string& aError) throw() {
-        failed(aSource, aError, false);
+void ConnectionManager::on(UserConnectionListener::Failed, UserConnection* aSource, const string& aError) noexcept {
+    failed(aSource, aError, false);
 }
 
-void ConnectionManager::on(UserConnectionListener::ProtocolError, UserConnection* aSource, const string& aError) throw() {
-        failed(aSource, aError, true);
+void ConnectionManager::on(UserConnectionListener::ProtocolError, UserConnection* aSource, const string& aError) noexcept {
+    failed(aSource, aError, true);
 }
 
 void ConnectionManager::disconnect(const UserPtr& aUser) {
@@ -810,7 +816,7 @@ void ConnectionManager::shutdown() {
 }
 
 // UserConnectionListener
-void ConnectionManager::on(UserConnectionListener::Supports, UserConnection* conn, const StringList& feat) throw() {
+void ConnectionManager::on(UserConnectionListener::Supports, UserConnection* conn, const StringList& feat) noexcept {
     for(StringList::const_iterator i = feat.begin(); i != feat.end(); ++i) {
         if(*i == UserConnection::FEATURE_MINISLOTS) {
             conn->setFlag(UserConnection::FLAG_SUPPORTS_MINISLOTS);
