@@ -13,11 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "stdinc.h"
-#include "DCPlusPlus.h"
 
 #include "NmdcHub.h"
 
@@ -36,15 +35,15 @@
 
 namespace dcpp {
 
-NmdcHub::NmdcHub(const string& aHubURL) :
-Client(aHubURL, '|', false),
+NmdcHub::NmdcHub(const string& aHubURL, bool secure) :
+Client(aHubURL, '|', secure),
 supportFlags(0),
 lastUpdate(0),
 lastProtectedIPsUpdate(0)
 {
 }
 
-NmdcHub::~NmdcHub() throw() {
+NmdcHub::~NmdcHub() {
     clearUsers();
 }
 
@@ -144,6 +143,9 @@ void NmdcHub::clearUsers() {
 
 void NmdcHub::updateFromTag(Identity& id, const string& tag) {
     StringTokenizer<string> tok(tag, ',');
+    string::size_type j;
+    size_t slots = 1;
+    id.set("US", Util::emptyString);
     for(StringIter i = tok.getTokens().begin(); i != tok.getTokens().end(); ++i) {
         if(i->length() < 2)
             continue;
@@ -157,9 +159,9 @@ void NmdcHub::updateFromTag(Identity& id, const string& tag) {
             id.set("HO", t.getTokens()[2]);
         } else if(i->compare(0, 2, "S:") == 0) {
             id.set("SL", i->substr(2));
-        } else if(i->find("V:") != string::npos) {
-            string::size_type j = i->find("V:");
-            i->erase(i->begin() + j, i->begin() + j + 2);
+            slots = Util::toUInt32(i->substr(2));
+        } else if((j = i->find("V:")) != string::npos) {
+            i->erase(i->begin(), i->begin() + j + 2);
             id.set("VE", *i);
         } else if(i->compare(0, 2, "M:") == 0) {
             if(i->size() == 3) {
@@ -168,13 +170,16 @@ void NmdcHub::updateFromTag(Identity& id, const string& tag) {
                 else
                     id.getUser()->setFlag(User::PASSIVE);
             }
+        } else if((j = i->find("L:")) != string::npos) {
+            i->erase(i->begin() + j, i->begin() + j + 2);
+            id.set("US", Util::toString(Util::toInt(*i) * 1024));
         }
     }
     /// @todo Think about this
     id.set("TA", '<' + tag + '>');
 }
 
-void NmdcHub::onLine(const string& aLine) throw() {
+void NmdcHub::onLine(const string& aLine) noexcept {
     if(aLine.length() == 0)
         return;
 
@@ -212,19 +217,19 @@ void NmdcHub::onLine(const string& aLine) throw() {
             return;
         }
 
-                ChatMessage chatMessage = { unescape(message), findUser(nick) };
+        ChatMessage chatMessage = { unescape(message), findUser(nick) };
 
-                if(!chatMessage.from) {
+        if(!chatMessage.from) {
             OnlineUser& o = getUser(nick);
             // Assume that messages from unknown users come from the hub
             o.getIdentity().setHub(true);
             o.getIdentity().setHidden(true);
             fire(ClientListener::UserUpdated(), this, o);
 
-                        chatMessage.from = &o;
+            chatMessage.from = &o;
         }
 
-                fire(ClientListener::Message(), this, chatMessage);
+        fire(ClientListener::Message(), this, chatMessage);
         return;
     }
 
@@ -384,6 +389,19 @@ void NmdcHub::onLine(const string& aLine) throw() {
         u.getIdentity().setHub(false);
 
         u.getIdentity().setConnection(connection);
+        u.getIdentity().setStatus(Util::toString(param[j-1]));
+
+        if(u.getIdentity().getStatus() & Identity::TLS) {
+            u.getUser()->setFlag(User::TLS);
+        } else {
+            u.getUser()->unsetFlag(User::TLS);
+        }
+
+        if(u.getIdentity().getStatus() & Identity::NAT) {
+            u.getUser()->setFlag(User::NAT_TRAVERSAL);
+        } else {
+            u.getUser()->unsetFlag(User::NAT_TRAVERSAL);
+        }
         i = j + 1;
         j = param.find('$', i);
 
@@ -434,9 +452,53 @@ void NmdcHub::onLine(const string& aLine) throw() {
         if(j+1 >= param.size()) {
             return;
         }
-        string port = param.substr(j+1);
+        string senderNick;
+        string port;
+
+        i = param.find(' ', j+1);
+        if(i == string::npos) {
+            port = param.substr(j+1);
+        } else {
+            senderNick = param.substr(i+1);
+            port = param.substr(j+1, i-j-1);
+        }
+
+        bool secure = false;
+        if(port[port.size() - 1] == 'S') {
+            port.erase(port.size() - 1);
+            if(CryptoManager::getInstance()->TLSOk()) {
+                secure = true;
+            }
+        }
+
+        if(BOOLSETTING(ALLOW_NATT)) {
+            if(port[port.size() - 1] == 'N') {
+                if(senderNick.empty())
+                    return;
+
+                port.erase(port.size() - 1);
+
+                // Trigger connection attempt sequence locally ...
+                ConnectionManager::getInstance()->nmdcConnect(server, static_cast<uint16_t>(Util::toInt(port)), sock->getLocalPort(),
+                BufferedSocket::NAT_CLIENT, getMyNick(), getHubUrl(), getEncoding(), secure);
+
+                // ... and signal other client to do likewise.
+                send("$ConnectToMe " + senderNick + " " + getLocalIp() + ":" + Util::toString(sock->getLocalPort()) + (secure ? "RS" : "R") + "|");
+                return;
+            } else if(port[port.size() - 1] == 'R') {
+                port.erase(port.size() - 1);
+
+                // Trigger connection attempt sequence locally
+                ConnectionManager::getInstance()->nmdcConnect(server, static_cast<uint16_t>(Util::toInt(port)), sock->getLocalPort(),
+                BufferedSocket::NAT_SERVER, getMyNick(), getHubUrl(), getEncoding(), secure);
+                return;
+            }
+        }
+
+        if(port.empty())
+            return;
         // For simplicity, we make the assumption that users on a hub have the same character encoding
-        ConnectionManager::getInstance()->nmdcConnect(server, (uint16_t)Util::toInt(port), getMyNick(), getHubUrl(), getEncoding());
+        ConnectionManager::getInstance()->nmdcConnect(server, static_cast<uint16_t>(Util::toInt(port)), getMyNick(), getHubUrl(), getEncoding(), secure);
     } else if(cmd == "$RevConnectToMe") {
         if(state != STATE_NORMAL) {
             return;
@@ -453,6 +515,11 @@ void NmdcHub::onLine(const string& aLine) throw() {
 
         if(isActive()) {
             connectToMe(*u);
+        } else if(BOOLSETTING(ALLOW_NATT) && (u->getIdentity().getStatus() & Identity::NAT)) {
+            bool secure = CryptoManager::getInstance()->TLSOk() && u->getUser()->isSet(User::TLS);
+            // NMDC v2.205 supports "$ConnectToMe sender_nick remote_nick ip:port", but many NMDC hubsofts block it
+            // sender_nick at the end should work at least in most used hubsofts
+            send("$ConnectToMe " + fromUtf8(u->getIdentity().getNick()) + " " + getLocalIp() + ":" + Util::toString(sock->getLocalPort()) + (secure ? "NS " : "N ") + fromUtf8(getMyNick()) + "|");
         } else {
             if(!u->getUser()->isSet(User::PASSIVE)) {
                 u->getUser()->setFlag(User::PASSIVE);
@@ -517,9 +584,9 @@ void NmdcHub::onLine(const string& aLine) throw() {
             if(j == string::npos)
                 return;
             string name = unescape(param.substr(i, j-i));
-                        // NMDC uses '\' as a separator but both ADC and our internal representation use '/'
-                        Util::replace("/", "//", name);
-                        Util::replace("\\", "/", name);
+            // NMDC uses '\' as a separator but both ADC and our internal representation use '/'
+            Util::replace("/", "//", name);
+            Util::replace("\\", "/", name);
             i = j+1;
             string command = unescape(param.substr(i, param.length() - i));
             fire(ClientListener::HubUserCommand(), this, type, ctx, name, command);
@@ -557,8 +624,13 @@ void NmdcHub::onLine(const string& aLine) throw() {
                 feat.push_back("TTHSearch");
                 feat.push_back("ZPipe0");
 
-                if(BOOLSETTING(USE_DHT))
-                    feat.push_back("DHT0");
+            if(CryptoManager::getInstance()->TLSOk())
+                feat.push_back("TLS");
+
+#ifdef WITH_DHT
+            if(BOOLSETTING(USE_DHT))
+                feat.push_back("DHT0");
+#endif
 
                 supports(feat);
             }
@@ -706,12 +778,9 @@ void NmdcHub::onLine(const string& aLine) throw() {
             return;
 
         string fromNick = param.substr(i+1, j-i-1);
-        if(fromNick.empty())
+        if(fromNick.empty() || param.size() < j + 2)
             return;
 
-        if(param.size() < j + 2) {
-            return;
-        }
         ChatMessage message = { unescape(param.substr(j + 2)), findUser(fromNick), &getUser(getMyNick()), findUser(rtNick) };
 
         if(!message.replyTo || !message.from) {
@@ -770,7 +839,9 @@ void NmdcHub::connectToMe(const OnlineUser& aUser) {
     dcdebug("NmdcHub::connectToMe %s\n", aUser.getIdentity().getNick().c_str());
     string nick = fromUtf8(aUser.getIdentity().getNick());
     ConnectionManager::getInstance()->nmdcExpect(nick, getMyNick(), getHubUrl());
-    send("$ConnectToMe " + nick + " " + getLocalIp() + ":" + Util::toString(ConnectionManager::getInstance()->getPort()) + "|");
+    bool secure = CryptoManager::getInstance()->TLSOk() && aUser.getUser()->isSet(User::TLS);
+    uint16_t port = secure ? ConnectionManager::getInstance()->getSecurePort() : ConnectionManager::getInstance()->getPort();
+    send("$ConnectToMe " + nick + " " + getLocalIp() + ":" + Util::toString(port) + (secure ? "S" : "") + "|");
 }
 
 void NmdcHub::revConnectToMe(const OnlineUser& aUser) {
@@ -789,7 +860,7 @@ void NmdcHub::myInfo(bool alwaysSend) {
 
     reloadSettings(false);
 
-    lastCounts = counts;
+    char StatusMode = Identity::NORMAL;
 
     string::size_type i;
 
@@ -800,13 +871,23 @@ void NmdcHub::myInfo(bool alwaysSend) {
         modeChar = 'A';
     else
         modeChar = 'P';
-string uploadSpeed;
+    string uploadSpeed;
     int upLimit = ThrottleManager::getInstance()->getUpLimit();
     if (upLimit > 0 && BOOLSETTING(THROTTLE_ENABLE)) {
         uploadSpeed = Util::toString(upLimit) + " KiB/s";
     } else {
         uploadSpeed = SETTING(UPLOAD_SPEED);
     }
+    if(Util::getAway()) {
+        StatusMode |= Identity::AWAY;
+    }
+    if(BOOLSETTING(ALLOW_NATT) && !isActive()) {
+            StatusMode |= Identity::NAT;
+    }
+    if (CryptoManager::getInstance()->TLSOk()) {
+            StatusMode |= Identity::TLS;
+    }
+
     bool gslotf = BOOLSETTING(SHOW_FREE_SLOTS_DESC);
     string gslot = "["+Util::toString(UploadManager::getInstance()->getFreeSlots())+"]";
     string uMin = (SETTING(MIN_UPLOAD_SPEED) == 0) ? Util::emptyString : ",O:" + Util::toString(SETTING(MIN_UPLOAD_SPEED));
@@ -815,9 +896,10 @@ string uploadSpeed;
         fromUtf8(escape((gslotf ? gslot :"")+getCurrentDescription())) + " <"+ getClientId().c_str() + ",M:" + modeChar + ",H:" + getCounts();
     string myInfoB = ",S:" + Util::toString(SETTING(SLOTS));
     string myInfoC = uMin +
-        ">$ $" + uploadSpeed + "\x01$" + fromUtf8(escape(SETTING(EMAIL))) + '$';
+        ">$ $" + uploadSpeed + StatusMode + "$" + fromUtf8(escape(SETTING(EMAIL))) + '$';
     string myInfoD = ShareManager::getInstance()->getShareSizeString() + "$|";
     // we always send A and C; however, B (slots) and D (share size) can frequently change so we delay them if needed
+    //printf("%s\n", (myInfoA + myInfoB + myInfoC + myInfoD).c_str());
     if(lastMyInfoA != myInfoA || lastMyInfoC != myInfoC ||
         alwaysSend || ((lastMyInfoB != myInfoB || lastMyInfoD != myInfoD) && lastUpdate + 15*60*1000 < GET_TICK())) {
         dcdebug("MyInfo %s...\n", getMyNick().c_str());
@@ -897,7 +979,7 @@ string NmdcHub::validateMessage(string tmp, bool reverse) {
 }
 
 void NmdcHub::privateMessage(const string& nick, const string& message) {
-        send("$To: " + fromUtf8(nick) + " From: " + fromUtf8(getMyNick()) + " $" + fromUtf8(escape("<" + getMyNick() + "> " + message)) + "|");
+    send("$To: " + fromUtf8(nick) + " From: " + fromUtf8(getMyNick()) + " $" + fromUtf8(escape("<" + getMyNick() + "> " + message)) + "|");
 }
 
 void NmdcHub::privateMessage(const OnlineUser& aUser, const string& aMessage, bool /*thirdPerson*/) {
@@ -938,14 +1020,14 @@ void NmdcHub::clearFlooders(uint64_t aTick) {
 }
 
 bool NmdcHub::isProtectedIP(const string& ip) {
-        if(find(protectedIPs.begin(), protectedIPs.end(), ip) != protectedIPs.end()) {
-                fire(ClientListener::StatusMessage(), this, str(F_("This hub is trying to use your client to spam %1%, please urge hub owner to fix this") % ip));
-                return true;
-        }
-        return false;
+    if(find(protectedIPs.begin(), protectedIPs.end(), ip) != protectedIPs.end()) {
+        fire(ClientListener::StatusMessage(), this, str(F_("This hub is trying to use your client to spam %1%, please urge hub owner to fix this") % ip));
+        return true;
+    }
+    return false;
 }
 
-void NmdcHub::on(Connected) throw() {
+void NmdcHub::on(Connected) noexcept {
     Client::on(Connected());
     if(state != STATE_PROTOCOL) {
         return;
@@ -958,7 +1040,7 @@ void NmdcHub::on(Connected) throw() {
     lastUpdate = 0;
 }
 
-void NmdcHub::on(Line, const string& aLine) throw() {
+void NmdcHub::on(Line, const string& aLine) noexcept {
 #ifdef LUA_SCRIPT
     if (onClientMessage(this, validateMessage(aLine, true)))
         return;
@@ -967,12 +1049,12 @@ void NmdcHub::on(Line, const string& aLine) throw() {
     onLine(aLine);
 }
 
-void NmdcHub::on(Failed, const string& aLine) throw() {
+void NmdcHub::on(Failed, const string& aLine) noexcept {
     clearUsers();
     Client::on(Failed(), aLine);
 }
 
-void NmdcHub::on(Second, uint64_t aTick) throw() {
+void NmdcHub::on(Second, uint64_t aTick) noexcept {
     Client::on(Second(), aTick);
 
     if(state == STATE_NORMAL && (aTick > (getLastActivity() + 120*1000)) ) {
@@ -980,25 +1062,25 @@ void NmdcHub::on(Second, uint64_t aTick) throw() {
     }
 }
 
-void NmdcHub::on(Minute, uint64_t aTick) throw() {
-        if(aTick > (lastProtectedIPsUpdate + 24*3600*1000)) {
-                protectedIPs.clear();
+void NmdcHub::on(Minute, uint64_t aTick) noexcept {
+    if(aTick > (lastProtectedIPsUpdate + 24*3600*1000)) {
+        protectedIPs.clear();
 
-                protectedIPs.push_back("dcpp.net");
-                protectedIPs.push_back("hublist.org");
-                protectedIPs.push_back("openhublist.org");
-                protectedIPs.push_back("dchublist.com");
-                protectedIPs.push_back("hublista.hu");
-                protectedIPs.push_back("adcportal.com");
-                for(StringIter i = protectedIPs.begin(); i != protectedIPs.end();) {
-                        *i = Socket::resolve(*i);
-                        if(Util::isPrivateIp(*i))
-                                i = protectedIPs.erase(i);
-                        else
-                                i++;
-                }
-                lastProtectedIPsUpdate = aTick;
+        protectedIPs.push_back("dcpp.net");
+        protectedIPs.push_back("hublist.org");
+        protectedIPs.push_back("openhublist.org");
+        protectedIPs.push_back("dchublist.com");
+        protectedIPs.push_back("hublista.hu");
+        protectedIPs.push_back("adcportal.com");
+        for(StringIter i = protectedIPs.begin(); i != protectedIPs.end();) {
+            *i = Socket::resolve(*i);
+            if(Util::isPrivateIp(*i))
+                i = protectedIPs.erase(i);
+            else
+                i++;
         }
+        lastProtectedIPsUpdate = aTick;
+    }
 }
 
 #ifdef LUA_SCRIPT
