@@ -13,11 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "stdinc.h"
-#include "DCPlusPlus.h"
 
 #include "SettingsManager.h"
 
@@ -51,8 +50,8 @@ const string SettingsManager::settingTags[] =
     "LogFileSystem",
     "LogFormatSystem", "LogFormatStatus", "TLSPrivateKeyFile",
     "TLSCertificateFile", "TLSTrustedCertificatesPath",
-    "Language", "SkipListShare", "InternetIp", "BindIfaceName", "DHTKey",
-    "DynDNSServer",
+    "Language", "SkipListShare", "InternetIp", "BindIfaceName",
+    "DHTKey", "DynDNSServer",
     "SENTRY",
     // Ints
     "IncomingConnections", "InPort", "Slots", "AutoFollow",
@@ -86,7 +85,8 @@ const string SettingsManager::settingTags[] =
     "SegmentedDL", "FollowLinks", "SendBloom",
     "Coral", "SearchFilterShared", "FinishedDLOnlyFull",
     "SearchMerge", "HashBufferSize", "HashBufferPopulate",
-    "HashBufferNoReserve", "HashBufferPrivate", "UseDHT", "DHTPort",
+    "HashBufferNoReserve", "HashBufferPrivate",
+    "UseDHT", "DHTPort",
     "ReconnectDelay", "AutoDetectIncomingConnection",
     "BandwidthLimitStart", "BandwidthLimitEnd", "EnableThrottle","TimeDependentThrottle",
     "MaxDownloadSpeedAlternate", "MaxUploadSpeedAlternate",
@@ -296,7 +296,7 @@ SettingsManager::SettingsManager()
     setDefault(BIND_IFACE_NAME, "");
     setDefault(MINIMUM_SEARCH_INTERVAL, 60);
     setDefault(DYNDNS_SERVER, "http://checkip.dyndns.org/index.html");
-    setDefault(DYNDNS_ENABLE, true);
+    setDefault(DYNDNS_ENABLE, false);
     setSearchTypeDefaults();
 }
 
@@ -357,27 +357,27 @@ void SettingsManager::load(string const& aFileName)
             xml.stepOut();
         }
 
-                xml.resetCurrentChild();
-                if(xml.findChild("SearchTypes")) {
-                        try {
-                                searchTypes.clear();
-                                xml.stepIn();
-                                while(xml.findChild("SearchType")) {
-                                        const string& extensions = xml.getChildData();
-                                        if(extensions.empty()) {
-                                                continue;
-                                        }
-                                        const string& name = xml.getChildAttrib("Id");
-                                        if(name.empty()) {
-                                                continue;
-                                        }
-                                        searchTypes[name] = StringTokenizer<string>(extensions, ';').getTokens();
-                                }
-                                xml.stepOut();
-                        } catch(const SimpleXMLException&) {
-                                setSearchTypeDefaults();
-                        }
+        xml.resetCurrentChild();
+        if(xml.findChild("SearchTypes")) {
+            try {
+                searchTypes.clear();
+                xml.stepIn();
+                while(xml.findChild("SearchType")) {
+                    const string& extensions = xml.getChildData();
+                    if(extensions.empty()) {
+                        continue;
+                    }
+                    const string& name = xml.getChildAttrib("Id");
+                    if(name.empty()) {
+                        continue;
+                    }
+                    searchTypes[name] = StringTokenizer<string>(extensions, ';').getTokens();
                 }
+                xml.stepOut();
+            } catch(const SimpleXMLException&) {
+                setSearchTypeDefaults();
+            }
+        }
 
         if(SETTING(PRIVATE_ID).length() != 39 || CID(SETTING(PRIVATE_ID)).isZero()) {
             set(PRIVATE_ID, CID::generate().toBase32());
@@ -429,7 +429,6 @@ void SettingsManager::load(string const& aFileName)
         if(CID(SETTING(PRIVATE_ID)).isZero())
             set(PRIVATE_ID, CID::generate().toBase32());
     }
-
     if (SETTING(DHT_KEY).length() != 39 || CID(SETTING(DHT_KEY)).isZero())
         set(DHT_KEY, CID::generate().toBase32());
 }
@@ -482,13 +481,13 @@ void SettingsManager::save(string const& aFileName) {
     }
     xml.stepOut();
 
-        xml.addTag("SearchTypes");
-        xml.stepIn();
-        for(SearchTypesIterC i = searchTypes.begin(); i != searchTypes.end(); ++i) {
-                xml.addTag("SearchType", Util::toString(";", i->second));
-                xml.addChildAttrib("Id", i->first);
-        }
-        xml.stepOut();
+    xml.addTag("SearchTypes");
+    xml.stepIn();
+    for(SearchTypesIterC i = searchTypes.begin(); i != searchTypes.end(); ++i) {
+        xml.addTag("SearchType", Util::toString(";", i->second));
+        xml.addChildAttrib("Id", i->first);
+    }
+    xml.stepOut();
 
     fire(SettingsManagerListener::Save(), xml);
 
@@ -507,14 +506,14 @@ void SettingsManager::save(string const& aFileName) {
 }
 
 void SettingsManager::validateSearchTypeName(const string& name) const {
-        if(name.empty() || (name.size() == 1 && name[0] >= '1' && name[0] <= '6')) {
-                throw SearchTypeException(_("Invalid search type name"));
-        }
-        for(int type = SearchManager::TYPE_ANY; type != SearchManager::TYPE_LAST; ++type) {
-                if(SearchManager::getTypeStr(type) == name) {
-                        throw SearchTypeException(_("This search type already exists"));
-                }
+    if(name.empty() || (name.size() == 1 && name[0] >= '1' && name[0] <= '6')) {
+        throw SearchTypeException(_("Invalid search type name"));
+    }
+    for(int type = SearchManager::TYPE_ANY; type != SearchManager::TYPE_LAST; ++type) {
+        if(SearchManager::getTypeStr(type) == name) {
+            throw SearchTypeException(_("This search type already exists"));
         }
+    }
 }
 
 void SettingsManager::setSearchTypeDefaults() {
@@ -529,46 +528,46 @@ void SettingsManager::setSearchTypeDefaults() {
 }
 
 void SettingsManager::addSearchType(const string& name, const StringList& extensions, bool validated) {
-        if(!validated) {
-                validateSearchTypeName(name);
-        }
+    if(!validated) {
+        validateSearchTypeName(name);
+    }
 
-        if(searchTypes.find(name) != searchTypes.end()) {
-                throw SearchTypeException(_("This search type already exists"));
-        }
+    if(searchTypes.find(name) != searchTypes.end()) {
+        throw SearchTypeException(_("This search type already exists"));
+    }
 
-        searchTypes[name] = extensions;
-        fire(SettingsManagerListener::SearchTypesChanged());
+    searchTypes[name] = extensions;
+    fire(SettingsManagerListener::SearchTypesChanged());
 }
 
 void SettingsManager::delSearchType(const string& name) {
-        validateSearchTypeName(name);
-        searchTypes.erase(name);
-        fire(SettingsManagerListener::SearchTypesChanged());
+    validateSearchTypeName(name);
+    searchTypes.erase(name);
+    fire(SettingsManagerListener::SearchTypesChanged());
 }
 
 void SettingsManager::renameSearchType(const string& oldName, const string& newName) {
-        validateSearchTypeName(newName);
-        StringList exts = getSearchType(oldName)->second;
-        addSearchType(newName, exts, true);
-        searchTypes.erase(oldName);
+    validateSearchTypeName(newName);
+    StringList exts = getSearchType(oldName)->second;
+    addSearchType(newName, exts, true);
+    searchTypes.erase(oldName);
 }
 
 void SettingsManager::modSearchType(const string& name, const StringList& extensions) {
-        getSearchType(name)->second = extensions;
-        fire(SettingsManagerListener::SearchTypesChanged());
+    getSearchType(name)->second = extensions;
+    fire(SettingsManagerListener::SearchTypesChanged());
 }
 
 const StringList& SettingsManager::getExtensions(const string& name) {
-        return getSearchType(name)->second;
+    return getSearchType(name)->second;
 }
 
 SettingsManager::SearchTypesIter SettingsManager::getSearchType(const string& name) {
-        SearchTypesIter ret = searchTypes.find(name);
-        if(ret == searchTypes.end()) {
-                throw SearchTypeException(_("No such search type"));
-        }
-        return ret;
+    SearchTypesIter ret = searchTypes.find(name);
+    if(ret == searchTypes.end()) {
+        throw SearchTypeException(_("No such search type"));
+    }
+    return ret;
 }
 
 bool SettingsManager::getType(const char* name, int& n, int& type) const {
