@@ -13,11 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "stdinc.h"
-#include "DCPlusPlus.h"
 
 #include "ShareManager.h"
 #include "AdcHub.h"
@@ -53,12 +52,7 @@
 #include <limits>
 
 namespace dcpp {
-#ifdef WITH_DHT
-void ShareManager::publish() {
-    Lock l(cs);
-    dht::IndexManager::getInstance()->createPublishQueue(tthIndex);
-}
-#endif
+
 ShareManager::ShareManager() : hits(0), xmlListLen(0), bzXmlListLen(0),
     xmlDirty(true), forceXmlRefresh(false), refreshDirs(false), update(false), initial(true), listN(0), refreshing(false),
     lastXmlUpdate(0), lastFullUpdate(GET_TICK()), bloom(1<<20)
@@ -77,10 +71,10 @@ ShareManager::~ShareManager() {
 
     join();
 
-        if(bzXmlRef.get()) {
-                bzXmlRef.reset();
-                File::deleteFile(getBZXmlFile());
-        }
+    if(bzXmlRef.get()) {
+        bzXmlRef.reset();
+        File::deleteFile(getBZXmlFile());
+    }
 }
 
 ShareManager::Directory::Directory(const string& aName, const ShareManager::Directory::Ptr& aParent) :
@@ -91,19 +85,19 @@ ShareManager::Directory::Directory(const string& aName, const ShareManager::Dire
 {
 }
 
-string ShareManager::Directory::getADCPath() const throw() {
+string ShareManager::Directory::getADCPath() const noexcept {
     if(!getParent())
         return '/' + name + '/';
     return getParent()->getADCPath() + name + '/';
 }
 
-string ShareManager::Directory::getFullName() const throw() {
+string ShareManager::Directory::getFullName() const noexcept {
     if(!getParent())
         return getName() + '\\';
     return getParent()->getFullName() + getName() + '\\';
 }
 
-void ShareManager::Directory::addType(uint32_t type) throw() {
+void ShareManager::Directory::addType(uint32_t type) noexcept {
     if(!hasType(type)) {
         fileTypes |= (1 << type);
         if(getParent())
@@ -111,7 +105,7 @@ void ShareManager::Directory::addType(uint32_t type) throw() {
     }
 }
 
-string ShareManager::Directory::getRealPath(const std::string& path) const throw(ShareException) {
+string ShareManager::Directory::getRealPath(const std::string& path) const {
     if(getParent()) {
         return getParent()->getRealPath(getName() + PATH_SEPARATOR_STR + path);
     } else {
@@ -119,13 +113,12 @@ string ShareManager::Directory::getRealPath(const std::string& path) const throw
     }
 }
 
-string ShareManager::findRealRoot(const string& virtualRoot, const string& virtualPath) const throw(ShareException) {
+string ShareManager::findRealRoot(const string& virtualRoot, const string& virtualPath) const {
     for(StringMap::const_iterator i = shares.begin(); i != shares.end(); ++i) {
         if(Util::stricmp(i->second, virtualRoot) == 0) {
             std::string name = i->first + virtualPath;
             dcdebug("Matching %s\n", name.c_str());
-//                      if(FileFindIter(name) != FileFindIter())
-                        if (File::getSize(name) != -1)//NOTE: see core 0.750
+            if (File::getSize(name) != -1)//NOTE: see core 0.750
                 return name;
             }
         }
@@ -133,14 +126,14 @@ string ShareManager::findRealRoot(const string& virtualRoot, const string& virtu
     throw ShareException(UserConnection::FILE_NOT_AVAILABLE);
 }
 
-int64_t ShareManager::Directory::getSize() const throw() {
+int64_t ShareManager::Directory::getSize() const noexcept {
     int64_t tmp = size;
     for(Map::const_iterator i = directories.begin(); i != directories.end(); ++i)
         tmp+=i->second->getSize();
     return tmp;
 }
 
-string ShareManager::toVirtual(const TTHValue& tth) const throw(ShareException) {
+string ShareManager::toVirtual(const TTHValue& tth) const {
     if(tth == bzXmlRoot) {
         return Transfer::USER_LIST_NAME_BZ;
     } else if(tth == xmlRoot) {
@@ -156,7 +149,7 @@ string ShareManager::toVirtual(const TTHValue& tth) const throw(ShareException)
     }
 }
 
-string ShareManager::toReal(const string& virtualFile) throw(ShareException) {
+string ShareManager::toReal(const string& virtualFile) {
     Lock l(cs);
     if(virtualFile == "MyList.DcLst") {
         throw ShareException("NMDC-style lists no longer supported, please upgrade your client");
@@ -168,41 +161,41 @@ string ShareManager::toReal(const string& virtualFile) throw(ShareException) {
     return findFile(virtualFile)->getRealPath();
 }
 
-StringList ShareManager::getRealPaths(const string& virtualPath) throw(ShareException) {
-        if(virtualPath.empty())
-                throw ShareException("empty virtual path");
+StringList ShareManager::getRealPaths(const string& virtualPath) {
+    if(virtualPath.empty())
+        throw ShareException("empty virtual path");
 
-        StringList ret;
+    StringList ret;
 
-        Lock l(cs);
+    Lock l(cs);
 
-        if(*(virtualPath.end() - 1) == '/') {
-                // directory
-                Directory::Ptr d = splitVirtual(virtualPath).first;
-
-                // imitate Directory::getRealPath
-                if(d->getParent()) {
-                        ret.push_back(d->getParent()->getRealPath(d->getName()));
-                } else {
-                        for(StringMap::const_iterator i = shares.begin(); i != shares.end(); ++i) {
-                                if(Util::stricmp(i->second, d->getName()) == 0) {
-                                        // remove the trailing path sep
-                                        if(FileFindIter(i->first.substr(0, i->first.size() - 1)) != FileFindIter()) {
-                                                ret.push_back(i->first);
-                                        }
-                                }
-                        }
-                }
+    if(*(virtualPath.end() - 1) == '/') {
+        // directory
+        Directory::Ptr d = splitVirtual(virtualPath).first;
 
+        // imitate Directory::getRealPath
+        if(d->getParent()) {
+            ret.push_back(d->getParent()->getRealPath(d->getName()));
         } else {
-                // file
-                ret.push_back(toReal(virtualPath));
+            for(StringMap::const_iterator i = shares.begin(); i != shares.end(); ++i) {
+                if(Util::stricmp(i->second, d->getName()) == 0) {
+                    // remove the trailing path sep
+                    if(FileFindIter(i->first.substr(0, i->first.size() - 1)) != FileFindIter()) {
+                        ret.push_back(i->first);
+                    }
+                }
+            }
         }
 
-        return ret;
+    } else {
+        // file
+        ret.push_back(toReal(virtualPath));
+    }
+
+    return ret;
 }
 
-TTHValue ShareManager::getTTH(const string& virtualFile) const throw(ShareException) {
+TTHValue ShareManager::getTTH(const string& virtualFile) const {
     Lock l(cs);
     if(virtualFile == Transfer::USER_LIST_NAME_BZ) {
         return bzXmlRoot;
@@ -231,7 +224,7 @@ MemoryInputStream* ShareManager::getTree(const string& virtualFile) const {
     return new MemoryInputStream(&buf[0], buf.size());
 }
 
-AdcCommand ShareManager::getFileInfo(const string& aFile) throw(ShareException) {
+AdcCommand ShareManager::getFileInfo(const string& aFile) {
     if(aFile == Transfer::USER_LIST_NAME) {
         generateXmlList();
         AdcCommand cmd(AdcCommand::CMD_RES);
@@ -267,17 +260,17 @@ AdcCommand ShareManager::getFileInfo(const string& aFile) throw(ShareException)
     return cmd;
 }
 
-pair<ShareManager::Directory::Ptr, string> ShareManager::splitVirtual(const string& virtualPath) const throw(ShareException) {
-        if(virtualPath.empty() || virtualPath[0] != '/') {
+pair<ShareManager::Directory::Ptr, string> ShareManager::splitVirtual(const string& virtualPath) const {
+    if(virtualPath.empty() || virtualPath[0] != '/') {
         throw ShareException(UserConnection::FILE_NOT_AVAILABLE);
     }
 
-        string::size_type i = virtualPath.find('/', 1);
+    string::size_type i = virtualPath.find('/', 1);
     if(i == string::npos || i == 1) {
         throw ShareException(UserConnection::FILE_NOT_AVAILABLE);
     }
 
-        DirList::const_iterator dmi = getByVirtual( virtualPath.substr(1, i - 1));
+    DirList::const_iterator dmi = getByVirtual( virtualPath.substr(1, i - 1));
     if(dmi == directories.end()) {
         throw ShareException(UserConnection::FILE_NOT_AVAILABLE);
     }
@@ -285,35 +278,35 @@ pair<ShareManager::Directory::Ptr, string> ShareManager::splitVirtual(const stri
     Directory::Ptr d = *dmi;
 
     string::size_type j = i + 1;
-        while((i = virtualPath.find('/', j)) != string::npos) {
-                Directory::MapIter mi = d->directories.find(virtualPath.substr(j, i - j));
+    while((i = virtualPath.find('/', j)) != string::npos) {
+        Directory::MapIter mi = d->directories.find(virtualPath.substr(j, i - j));
         j = i + 1;
         if(mi == d->directories.end())
             throw ShareException(UserConnection::FILE_NOT_AVAILABLE);
         d = mi->second;
     }
 
-        return make_pair(d, virtualPath.substr(j));
+    return make_pair(d, virtualPath.substr(j));
 }
 
-ShareManager::Directory::File::Set::const_iterator ShareManager::findFile(const string& virtualFile) const throw(ShareException) {
-        if(virtualFile.compare(0, 4, "TTH/") == 0) {
-                HashFileMap::const_iterator i = tthIndex.find(TTHValue(virtualFile.substr(4)));
-                if(i == tthIndex.end()) {
-                        throw ShareException(UserConnection::FILE_NOT_AVAILABLE);
-                }
-                return i->second;
+ShareManager::Directory::File::Set::const_iterator ShareManager::findFile(const string& virtualFile) const {
+    if(virtualFile.compare(0, 4, "TTH/") == 0) {
+        HashFileMap::const_iterator i = tthIndex.find(TTHValue(virtualFile.substr(4)));
+        if(i == tthIndex.end()) {
+            throw ShareException(UserConnection::FILE_NOT_AVAILABLE);
         }
+        return i->second;
+    }
 
-        pair<Directory::Ptr, string> v = splitVirtual(virtualFile);
-        Directory::File::Set::const_iterator it = find_if(v.first->files.begin(), v.first->files.end(),
-                Directory::File::StringComp(v.second));
-        if(it == v.first->files.end())
+    pair<Directory::Ptr, string> v = splitVirtual(virtualFile);
+    Directory::File::Set::const_iterator it = find_if(v.first->files.begin(), v.first->files.end(),
+            Directory::File::StringComp(v.second));
+    if(it == v.first->files.end())
         throw ShareException(UserConnection::FILE_NOT_AVAILABLE);
     return it;
 }
 
-string ShareManager::validateVirtual(const string& aVirt) const throw() {
+string ShareManager::validateVirtual(const string& aVirt) const noexcept {
     string tmp = aVirt;
     string::size_type idx = 0;
 
@@ -323,7 +316,7 @@ string ShareManager::validateVirtual(const string& aVirt) const throw() {
     return tmp;
 }
 
-bool ShareManager::hasVirtual(const string& virtualName) const throw() {
+bool ShareManager::hasVirtual(const string& virtualName) const noexcept {
     Lock l(cs);
     return getByVirtual(virtualName) != directories.end();
 }
@@ -414,15 +407,15 @@ private:
     size_t depth;
 };
 
-bool ShareManager::loadCache() throw() {
+bool ShareManager::loadCache() noexcept {
     try {
         ShareLoader loader(directories);
-                SimpleXMLReader xml(&loader);
+        SimpleXMLReader xml(&loader);
 
         dcpp::File ff(Util::getPath(Util::PATH_USER_CONFIG) + "files.xml.bz2", dcpp::File::READ, dcpp::File::OPEN);
         FilteredInputStream<UnBZFilter, false> f(&ff);
 
-                xml.parse(f);
+        xml.parse(f);
 
         for(DirList::const_iterator i = directories.begin(); i != directories.end(); ++i) {
             const Directory::Ptr& d = *i;
@@ -448,7 +441,7 @@ void ShareManager::save(SimpleXML& aXml) {
     aXml.stepOut();
 }
 
-void ShareManager::addDirectory(const string& realPath, const string& virtualName) throw(ShareException) {
+void ShareManager::addDirectory(const string& realPath, const string& virtualName) {
     if(realPath.empty() || virtualName.empty()) {
         throw ShareException(_("No directory specified"));
     }
@@ -539,10 +532,10 @@ void ShareManager::Directory::merge(const Directory::Ptr& source) {
             if(directories.find(i->getName()) != directories.end()) {
                 dcdebug("Directory named the same as file");
             } else {
-                                std::pair<File::Set::iterator, bool> added = files.insert(*i);
-                                if(added.second) {
-                                        const_cast<File&>(*added.first).setParent(this);
-                                }
+                std::pair<File::Set::iterator, bool> added = files.insert(*i);
+                if(added.second) {
+                    const_cast<File&>(*added.first).setParent(this);
+                }
             }
         }
     }
@@ -587,12 +580,12 @@ void ShareManager::removeDirectory(const string& realPath) {
     setDirty();
 }
 
-void ShareManager::renameDirectory(const string& realPath, const string& virtualName) throw(ShareException) {
+void ShareManager::renameDirectory(const string& realPath, const string& virtualName) {
     removeDirectory(realPath);
     addDirectory(realPath, virtualName);
 }
 
-ShareManager::DirList::const_iterator ShareManager::getByVirtual(const string& virtualName) const throw() {
+ShareManager::DirList::const_iterator ShareManager::getByVirtual(const string& virtualName) const noexcept {
     for(DirList::const_iterator i = directories.begin(); i != directories.end(); ++i) {
         if(Util::stricmp((*i)->getName(), virtualName) == 0) {
             return i;
@@ -601,7 +594,7 @@ ShareManager::DirList::const_iterator ShareManager::getByVirtual(const string& v
     return directories.end();
 }
 
-int64_t ShareManager::getShareSize(const string& realPath) const throw() {
+int64_t ShareManager::getShareSize(const string& realPath) const noexcept {
     Lock l(cs);
     dcassert(realPath.size()>0);
     StringMap::const_iterator i = shares.find(realPath);
@@ -615,7 +608,7 @@ int64_t ShareManager::getShareSize(const string& realPath) const throw() {
     return -1;
 }
 
-int64_t ShareManager::getShareSize() const throw() {
+int64_t ShareManager::getShareSize() const noexcept {
     Lock l(cs);
     int64_t tmp = 0;
     for(HashFileMap::const_iterator i = tthIndex.begin(); i != tthIndex.end(); ++i) {
@@ -624,7 +617,7 @@ int64_t ShareManager::getShareSize() const throw() {
     return tmp;
 }
 
-size_t ShareManager::getSharedFiles() const throw() {
+size_t ShareManager::getSharedFiles() const noexcept {
     Lock l(cs);
     return tthIndex.size();
 }
@@ -731,9 +724,9 @@ bool ShareManager::checkHidden(const string& aName) const
 
         if (i != string::npos)
         {
-                string dir = path.substr(i + 1);
-                if (dir[0] == '.')
-                        hidden = true;
+            string dir = path.substr(i + 1);
+            if (dir[0] == '.')
+                hidden = true;
         }
 
         return (BOOLSETTING(SHARE_HIDDEN) || !hidden);
@@ -773,11 +766,10 @@ void ShareManager::updateIndices(Directory& dir, const Directory::File::Set::ite
     } else {
         if(!SETTING(LIST_DUPES)) {
             try {
-            LogManager::getInstance()->message(str(F_("Duplicate file will not be shared: %1% (Size: %2% B) Dupe matched against: %3%")
-            % Util::addBrackets(dir.getRealPath(f.getName())) % Util::toString(f.getSize()) % Util::addBrackets(j->second->getParent()->getRealPath(j->second->getName()))));
+                LogManager::getInstance()->message(str(F_("Duplicate file will not be shared: %1% (Size: %2% B) Dupe matched against: %3%")
+                % Util::addBrackets(dir.getRealPath(f.getName())) % Util::toString(f.getSize()) % Util::addBrackets(j->second->getParent()->getRealPath(j->second->getName()))));
             dir.files.erase(i);
-            } catch (const ShareException&) {
-            }
+            } catch (const ShareException&) { }
             return;
         }
     }
@@ -793,7 +785,7 @@ void ShareManager::updateIndices(Directory& dir, const Directory::File::Set::ite
 #endif
 }
 
-void ShareManager::refresh(bool dirs /* = false */, bool aUpdate /* = true */, bool block /* = false */) throw() {
+void ShareManager::refresh(bool dirs /* = false */, bool aUpdate /* = true */, bool block /* = false */) noexcept {
     if(refreshing.exchange(true) == true) {
         LogManager::getInstance()->message(_("File list refresh in progress, please wait for it to finish before trying to refresh again"));
         return;
@@ -820,7 +812,7 @@ void ShareManager::refresh(bool dirs /* = false */, bool aUpdate /* = true */, b
     }
 }
 
-StringPairList ShareManager::getDirectories() const throw() {
+StringPairList ShareManager::getDirectories() const noexcept {
     Lock l(cs);
     StringPairList ret;
     for(StringMap::const_iterator i = shares.begin(); i != shares.end(); ++i) {
@@ -942,7 +934,7 @@ void ShareManager::generateXmlList() {
             try {
                 File::copyFile(XmlListFileName, XmlListFileName + ".bak");
             } catch(const FileException&) { }
-            bzXmlRef = auto_ptr<File>(new File(newXmlName, File::READ, File::OPEN));
+            bzXmlRef = unique_ptr<File>(new File(newXmlName, File::READ, File::OPEN));
             setBZXmlFile(newXmlName);
             bzXmlListLen = File::getSize(newXmlName);
             LogManager::getInstance()->message(str(F_("File list %1% generated") % Util::addBrackets(bzXmlFile)));
@@ -1158,7 +1150,7 @@ static bool checkType(const string& aString, int aType) {
     return false;
 }
 
-SearchManager::TypeModes ShareManager::getType(const string& aFileName) const throw() {
+SearchManager::TypeModes ShareManager::getType(const string& aFileName) const noexcept {
     if(aFileName[aFileName.length() - 1] == PATH_SEPARATOR) {
         return SearchManager::TYPE_DIRECTORY;
     }
@@ -1188,19 +1180,19 @@ SearchManager::TypeModes ShareManager::getType(const string& aFileName) const th
  * has been matched in the directory name. This new stringlist should also be used in all descendants,
  * but not the parents...
  */
-void ShareManager::Directory::search(SearchResultList& aResults, StringSearch::List& aStrings, int aSearchType, int64_t aSize, int aFileType, Client* aClient, StringList::size_type maxResults) const throw() {
+void ShareManager::Directory::search(SearchResultList& aResults, StringSearch::List& aStrings, int aSearchType, int64_t aSize, int aFileType, Client* aClient, StringList::size_type maxResults) const noexcept {
     // Skip everything if there's nothing to find here (doh! =)
     if(!hasType(aFileType))
         return;
 
     StringSearch::List* cur = &aStrings;
-    auto_ptr<StringSearch::List> newStr;
+    unique_ptr<StringSearch::List> newStr;
 
     // Find any matches in the directory name
     for(StringSearch::List::const_iterator k = aStrings.begin(); k != aStrings.end(); ++k) {
         if(k->match(name)) {
             if(!newStr.get()) {
-                newStr = auto_ptr<StringSearch::List>(new StringSearch::List(aStrings));
+                newStr = unique_ptr<StringSearch::List>(new StringSearch::List(aStrings));
             }
             newStr->erase(remove(newStr->begin(), newStr->end(), *k), newStr->end());
         }
@@ -1251,7 +1243,7 @@ void ShareManager::Directory::search(SearchResultList& aResults, StringSearch::L
     }
 }
 
-void ShareManager::search(SearchResultList& results, const string& aString, int aSearchType, int64_t aSize, int aFileType, Client* aClient, StringList::size_type maxResults) throw() {
+void ShareManager::search(SearchResultList& results, const string& aString, int aSearchType, int64_t aSize, int aFileType, Client* aClient, StringList::size_type maxResults) noexcept {
     Lock l(cs);
     if(aFileType == SearchManager::TYPE_TTH) {
         if(aString.compare(0, 4, "TTH:") == 0) {
@@ -1348,17 +1340,17 @@ bool ShareManager::AdcSearch::hasExt(const string& name) {
     return false;
 }
 
-void ShareManager::Directory::search(SearchResultList& aResults, AdcSearch& aStrings, StringList::size_type maxResults) const throw() {
+void ShareManager::Directory::search(SearchResultList& aResults, AdcSearch& aStrings, StringList::size_type maxResults) const noexcept {
     StringSearch::List* cur = aStrings.include;
     StringSearch::List* old = aStrings.include;
 
-    auto_ptr<StringSearch::List> newStr;
+    unique_ptr<StringSearch::List> newStr;
 
     // Find any matches in the directory name
     for(StringSearch::List::iterator k = cur->begin(); k != cur->end(); ++k) {
         if(k->match(name) && !aStrings.isExcluded(name)) {
             if(!newStr.get()) {
-                newStr = auto_ptr<StringSearch::List>(new StringSearch::List(*cur));
+                newStr = unique_ptr<StringSearch::List>(new StringSearch::List(*cur));
             }
             newStr->erase(remove(newStr->begin(), newStr->end(), *k), newStr->end());
         }
@@ -1415,7 +1407,7 @@ void ShareManager::Directory::search(SearchResultList& aResults, AdcSearch& aStr
     aStrings.include = old;
 }
 
-void ShareManager::search(SearchResultList& results, const StringList& params, StringList::size_type maxResults) throw() {
+void ShareManager::search(SearchResultList& results, const StringList& params, StringList::size_type maxResults) noexcept {
     AdcSearch srch(params);
 
     Lock l(cs);
@@ -1471,7 +1463,7 @@ ShareManager::Directory::Ptr ShareManager::getDirectory(const string& fname) {
     return Directory::Ptr();
 }
 
-void ShareManager::on(QueueManagerListener::FileMoved, const string& n) throw() {
+void ShareManager::on(QueueManagerListener::FileMoved, const string& n) noexcept {
     if(BOOLSETTING(ADD_FINISHED_INSTANTLY)) {
         // Check if finished download is supposed to be shared
         Lock l(cs);
@@ -1489,7 +1481,7 @@ void ShareManager::on(QueueManagerListener::FileMoved, const string& n) throw()
     }
 }
 
-void ShareManager::on(HashManagerListener::TTHDone, const string& fname, const TTHValue& root) throw() {
+void ShareManager::on(HashManagerListener::TTHDone, const string& fname, const TTHValue& root) noexcept {
     Lock l(cs);
     Directory::Ptr d = getDirectory(fname);
     if(d) {
@@ -1512,13 +1504,11 @@ void ShareManager::on(HashManagerListener::TTHDone, const string& fname, const T
     }
 }
 
-void ShareManager::on(TimerManagerListener::Minute, uint64_t tick) throw() {
+void ShareManager::on(TimerManagerListener::Minute, uint64_t tick) noexcept {
     if (SETTING(AUTO_REFRESH_TIME) > 0) {
-        //if (Util::getUpTime() > 5 * 60) { // [+] IRainman: disabling update file list immediately after startup
-            if (lastFullUpdate + SETTING(AUTO_REFRESH_TIME) * 60 * 1000 < tick) {
-                refresh(true, true);
-            }
-        //}
+        if (lastFullUpdate + SETTING(AUTO_REFRESH_TIME) * 60 * 1000 < tick) {
+            refresh(true, true);
+        }
     }
 }
 
