@@ -13,17 +13,22 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "stdinc.h"
-#include "DCPlusPlus.h"
 
 #include "Socket.h"
 #include "format.h"
 #include "SettingsManager.h"
 #include "TimerManager.h"
 
+#ifdef __MINGW32__
+#ifndef EADDRNOTAVAIL
+#define EADDRNOTAVAIL WSAEADDRNOTAVAIL
+#endif
+#endif
+
 #ifndef MSG_NOSIGNAL
 #define MSG_NOSIGNAL 0
 #endif
@@ -59,14 +64,14 @@ uint16_t Socket::udpPort;
 
 #ifdef _DEBUG
 
-SocketException::SocketException(int aError) throw() {
+SocketException::SocketException(int aError) noexcept {
     error = "SocketException: " + errorToString(aError);
     dcdebug("Thrown: %s\n", error.c_str());
 }
 
 #else // _DEBUG
 
-SocketException::SocketException(int aError) throw() : Exception(errorToString(aError)) { }
+SocketException::SocketException(int aError) noexcept : Exception(errorToString(aError)) { }
 
 #endif
 
@@ -74,7 +79,7 @@ Socket::Stats Socket::stats = { 0, 0 };
 
 static const uint32_t SOCKS_TIMEOUT = 30000;
 
-string SocketException::errorToString(int aError) throw() {
+string SocketException::errorToString(int aError) noexcept {
     string msg = Util::translateError(aError);
     if(msg.empty()) {
         msg = str(F_("Unknown error: 0x%1$x") % aError);
@@ -82,7 +87,7 @@ string SocketException::errorToString(int aError) throw() {
     return msg;
 }
 
-void Socket::create(int aType /* = TYPE_TCP */) throw(SocketException) {
+void Socket::create(int aType /* = TYPE_TCP */) {
     if(sock != INVALID_SOCKET)
         disconnect();
 
@@ -104,7 +109,7 @@ void Socket::create(int aType /* = TYPE_TCP */) throw(SocketException) {
         setSocketOpt(IP_TOS, IPTOS_TOS(SETTING(IP_TOS_VALUE)));
 }
 
-void Socket::accept(const Socket& listeningSocket) throw(SocketException) {
+void Socket::accept(const Socket& listeningSocket) {
     if(sock != INVALID_SOCKET) {
         disconnect();
     }
@@ -159,7 +164,7 @@ static string getIfaceI4 (const string &iface){
 #endif
 }
 
-uint16_t Socket::bind(uint16_t aPort, const string& aIp /* = 0.0.0.0 */) throw (SocketException){
+uint16_t Socket::bind(uint16_t aPort, const string& aIp /* = 0.0.0.0 */) {
     sockaddr_in sock_addr;
 
     sock_addr.sin_family = AF_INET;
@@ -176,12 +181,12 @@ uint16_t Socket::bind(uint16_t aPort, const string& aIp /* = 0.0.0.0 */) throw (
     return ntohs(sock_addr.sin_port);
 }
 
-void Socket::listen() throw(SocketException) {
+void Socket::listen() {
     check(::listen(sock, 20));
     connected = true;
 }
 
-void Socket::connect(const string& aAddr, uint16_t aPort) throw(SocketException) {
+void Socket::connect(const string& aAddr, uint16_t aPort) {
     sockaddr_in serv_addr;
 
     if(sock == INVALID_SOCKET) {
@@ -217,7 +222,7 @@ namespace {
     }
 }
 
-void Socket::socksConnect(const string& aAddr, uint16_t aPort, uint32_t timeout) throw(SocketException) {
+void Socket::socksConnect(const string& aAddr, uint16_t aPort, uint32_t timeout) {
 
     if(SETTING(SOCKS_SERVER).empty() || SETTING(SOCKS_PORT) == 0) {
         throw SocketException(_("The socks server failed establish a connection"));
@@ -275,7 +280,7 @@ void Socket::socksConnect(const string& aAddr, uint16_t aPort, uint32_t timeout)
     setIp(inet_ntoa(sock_addr));
 }
 
-void Socket::socksAuth(uint32_t timeout) throw(SocketException) {
+void Socket::socksAuth(uint32_t timeout) {
     vector<uint8_t> connStr;
 
     uint64_t start = GET_TICK();
@@ -330,19 +335,19 @@ void Socket::socksAuth(uint32_t timeout) throw(SocketException) {
     }
 }
 
-int Socket::getSocketOptInt(int option) throw(SocketException) {
+int Socket::getSocketOptInt(int option) {
     int val;
     socklen_t len = sizeof(val);
     check(::getsockopt(sock, SOL_SOCKET, option, (char*)&val, &len));
     return val;
 }
 
-void Socket::setSocketOpt(int option, int val) throw(SocketException) {
+void Socket::setSocketOpt(int option, int val) {
     int len = sizeof(val);
     check(::setsockopt(sock, SOL_SOCKET, option, (char*)&val, len));
 }
 
-int Socket::read(void* aBuffer, int aBufLen) throw(SocketException) {
+int Socket::read(void* aBuffer, int aBufLen) {
     int len = 0;
 
     dcassert(type == TYPE_TCP || type == TYPE_UDP);
@@ -362,7 +367,7 @@ int Socket::read(void* aBuffer, int aBufLen) throw(SocketException) {
     return len;
 }
 
-int Socket::read(void* aBuffer, int aBufLen, sockaddr_in &remote) throw(SocketException) {
+int Socket::read(void* aBuffer, int aBufLen, sockaddr_in &remote) {
     dcassert(type == TYPE_UDP);
 
     sockaddr_in remote_addr = { 0 };
@@ -381,7 +386,7 @@ int Socket::read(void* aBuffer, int aBufLen, sockaddr_in &remote) throw(SocketEx
     return len;
 }
 
-int Socket::readAll(void* aBuffer, int aBufLen, uint32_t timeout) throw(SocketException) {
+int Socket::readAll(void* aBuffer, int aBufLen, uint32_t timeout) {
     uint8_t* buf = (uint8_t*)aBuffer;
     int i = 0;
     while(i < aBufLen) {
@@ -400,7 +405,7 @@ int Socket::readAll(void* aBuffer, int aBufLen, uint32_t timeout) throw(SocketEx
     return i;
 }
 
-void Socket::writeAll(const void* aBuffer, int aLen, uint32_t timeout) throw(SocketException) {
+void Socket::writeAll(const void* aBuffer, int aLen, uint32_t timeout) {
     const uint8_t* buf = (const uint8_t*)aBuffer;
     int pos = 0;
     // No use sending more than this at a time...
@@ -417,7 +422,7 @@ void Socket::writeAll(const void* aBuffer, int aLen, uint32_t timeout) throw(Soc
     }
 }
 
-int Socket::write(const void* aBuffer, int aLen) throw(SocketException) {
+int Socket::write(const void* aBuffer, int aLen) {
     int sent;
     do {
         sent = ::send(sock, (const char*)aBuffer, aLen, MSG_NOSIGNAL);
@@ -436,7 +441,7 @@ int Socket::write(const void* aBuffer, int aLen) throw(SocketException) {
 * @param aLen Data length
 * @throw SocketExcpetion Send failed.
 */
-void Socket::writeTo(const string& aAddr, uint16_t aPort, const void* aBuffer, int aLen, bool proxy) throw(SocketException) {
+void Socket::writeTo(const string& aAddr, uint16_t aPort, const void* aBuffer, int aLen, bool proxy) {
     if(aLen <= 0)
         return;
 
@@ -510,7 +515,7 @@ void Socket::writeTo(const string& aAddr, uint16_t aPort, const void* aBuffer, i
  * @return WAIT_*** ored together of the current state.
  * @throw SocketException Select or the connection attempt failed.
  */
-int Socket::wait(uint32_t millis, int waitFor) throw(SocketException) {
+int Socket::wait(uint32_t millis, int waitFor) {
     timeval tv;
     fd_set rfd, wfd, efd;
     fd_set *rfdp = NULL, *wfdp = NULL;
@@ -628,7 +633,7 @@ string Socket::resolve(const string& aDns) {
 #endif
 }
 
-string Socket::getLocalIp() throw() {
+string Socket::getLocalIp() noexcept {
     if(sock == INVALID_SOCKET)
         return Util::emptyString;
 
@@ -640,7 +645,7 @@ string Socket::getLocalIp() throw() {
     return Util::emptyString;
 }
 
-uint16_t Socket::getLocalPort() throw() {
+uint16_t Socket::getLocalPort() noexcept {
     if(sock == INVALID_SOCKET)
         return 0;
 
@@ -696,12 +701,12 @@ void Socket::socksUpdated() {
     }
 }
 
-void Socket::shutdown() throw() {
+void Socket::shutdown() noexcept {
     if(sock != INVALID_SOCKET)
         ::shutdown(sock, 2);
 }
 
-void Socket::close() throw() {
+void Socket::close() noexcept {
     if(sock != INVALID_SOCKET) {
 #ifdef _WIN32
         ::closesocket(sock);
@@ -713,7 +718,7 @@ void Socket::close() throw() {
     }
 }
 
-void Socket::disconnect() throw() {
+void Socket::disconnect() noexcept {
     shutdown();
     close();
 }
