@@ -13,35 +13,30 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "stdinc.h"
-#include "DCPlusPlus.h"
+#include "Thread.h"
 
 #include "format.h"
-#include "Thread.h"
 
 namespace dcpp {
 
-#ifndef _WIN32
-pthread_mutex_t Thread::mtx = PTHREAD_MUTEX_INITIALIZER;
-#endif
-
 #ifdef _WIN32
-void Thread::start() throw(ThreadException) {
-	join();
-	if( (threadHandle = CreateThread(NULL, 0, &starter, this, 0, &threadId)) == NULL) {
-		throw ThreadException(_("Unable to create thread"));
-	}
+void Thread::start() {
+    join();
+    if( (threadHandle = CreateThread(NULL, 0, &starter, this, 0, &threadId)) == NULL) {
+        throw ThreadException(_("Unable to create thread"));
+    }
 }
 
 #else
-void Thread::start() throw(ThreadException) {
-	join();
-	if(pthread_create(&threadHandle, NULL, &starter, this) != 0) {
-		throw ThreadException(_("Unable to create thread"));
-	}
+void Thread::start() {
+    join();
+    if(pthread_create(&threadHandle, NULL, &starter, this) != 0) {
+        throw ThreadException(_("Unable to create thread"));
+    }
 }
 #endif
 
