@@ -13,11 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "stdinc.h"
-#include "DCPlusPlus.h"
 
 #include "UploadManager.h"
 
@@ -42,12 +41,12 @@ namespace dcpp {
 
 static const string UPLOAD_AREA = "Uploads";
 
-UploadManager::UploadManager() throw() : running(0), extra(0), lastGrant(0), limits(NULL), lastFreeSlots(-1) {
+UploadManager::UploadManager() noexcept : running(0), extra(0), lastGrant(0), limits(NULL), lastFreeSlots(-1) {
     ClientManager::getInstance()->addListener(this);
     TimerManager::getInstance()->addListener(this);
 }
 
-UploadManager::~UploadManager() throw() {
+UploadManager::~UploadManager() {
     TimerManager::getInstance()->removeListener(this);
     ClientManager::getInstance()->removeListener(this);
     while(true) {
@@ -168,68 +167,68 @@ bool UploadManager::prepareFile(UserConnection& aSource, const string& aType, co
                 sourceFile = target;
 
                 try {
-                        File* f = new File(sourceFile, File::READ, File::OPEN | File::SHARED);
+                    File* f = new File(sourceFile, File::READ, File::OPEN | File::SHARED);
 
-                        start = aStartPos;
-                        fileSize = f->getSize();
-                        size = (aBytes == -1) ? fileSize - start : aBytes;
+                    start = aStartPos;
+                    fileSize = f->getSize();
+                    size = (aBytes == -1) ? fileSize - start : aBytes;
 
-                        if((start + size) > fileSize) {
-                                aSource.fileNotAvail();
-                                delete f;
-                                return false;
-                        }
+                    if((start + size) > fileSize) {
+                            aSource.fileNotAvail();
+                            delete f;
+                            return false;
+                    }
 
-                        f->setPos(start);
-                        is = f;
+                    f->setPos(start);
+                    is = f;
 
-                        if((start + size) < fileSize) {
-                                is = new LimitedInputStream<true>(is, size);
-                        }
+                    if((start + size) < fileSize) {
+                            is = new LimitedInputStream<true>(is, size);
+                    }
 
-                        partial = true;
-                        type = Transfer::TYPE_FILE;
-                        goto ok;
+                    partial = true;
+                    type = Transfer::TYPE_FILE;
+                    goto ok;
                 } catch(const Exception&) {
-                        aSource.fileNotAvail();
-                        //aSource.disconnect();
-                        delete is;
-                        return false;
+                    aSource.fileNotAvail();
+                    //aSource.disconnect();
+                    delete is;
+                    return false;
                 }
             } else {
                 // Share finished file
                 target = FinishedManager::getInstance()->getTarget(fileHash.toBase32());
 
                 if(!target.empty() && Util::fileExists(target)){
-                        sourceFile = target;
-                        try {
-                            File* f = new File(sourceFile, File::READ, File::OPEN | File::SHARED);
+                    sourceFile = target;
+                    try {
+                        File* f = new File(sourceFile, File::READ, File::OPEN | File::SHARED);
 
-                            start = aStartPos;
-                            int64_t sz = f->getSize();
-                            size = (aBytes == -1) ? sz - start : aBytes;
-                            fileSize = sz;
+                        start = aStartPos;
+                        int64_t sz = f->getSize();
+                        size = (aBytes == -1) ? sz - start : aBytes;
+                        fileSize = sz;
 
-                            if((start + size) > sz) {
-                                aSource.fileNotAvail();
-                                delete f;
-                                return false;
-                            }
-
-                            f->setPos(start);
-                            is = f;
-                            if((start + size) < sz) {
-                                is = new LimitedInputStream<true>(is, size);
-                            }
-
-                            partial = true;
-                            type = Transfer::TYPE_FILE;
-                            goto ok;
-                        }catch(const Exception&){
+                        if((start + size) > sz) {
                             aSource.fileNotAvail();
-                            delete is;
+                            delete f;
                             return false;
                         }
+
+                        f->setPos(start);
+                        is = f;
+                        if((start + size) < sz) {
+                            is = new LimitedInputStream<true>(is, size);
+                        }
+
+                        partial = true;
+                        type = Transfer::TYPE_FILE;
+                        goto ok;
+                    }catch(const Exception&){
+                        aSource.fileNotAvail();
+                        delete is;
+                        return false;
+                    }
                 }
             }
         }
@@ -343,7 +342,7 @@ void UploadManager::reserveSlot(const HintedUser& aUser) {
         ClientManager::getInstance()->connect(aUser, Util::toString(Util::rand()));
 }
 
-void UploadManager::on(UserConnectionListener::Get, UserConnection* aSource, const string& aFile, int64_t aResume) throw() {
+void UploadManager::on(UserConnectionListener::Get, UserConnection* aSource, const string& aFile, int64_t aResume) noexcept {
     if(aSource->getState() != UserConnection::STATE_GET) {
         dcdebug("UM::onGet Bad state, ignoring\n");
         return;
@@ -355,7 +354,7 @@ void UploadManager::on(UserConnectionListener::Get, UserConnection* aSource, con
     }
 }
 
-void UploadManager::on(UserConnectionListener::Send, UserConnection* aSource) throw() {
+void UploadManager::on(UserConnectionListener::Send, UserConnection* aSource) noexcept {
     if(aSource->getState() != UserConnection::STATE_SEND) {
         dcdebug("UM::onSend Bad state, ignoring\n");
         return;
@@ -371,7 +370,7 @@ void UploadManager::on(UserConnectionListener::Send, UserConnection* aSource) th
     fire(UploadManagerListener::Starting(), u);
 }
 
-void UploadManager::on(AdcCommand::GET, UserConnection* aSource, const AdcCommand& c) throw() {
+void UploadManager::on(AdcCommand::GET, UserConnection* aSource, const AdcCommand& c) noexcept {
     if(aSource->getState() != UserConnection::STATE_GET) {
         dcdebug("UM::onGET Bad state, ignoring\n");
         return;
@@ -413,7 +412,7 @@ void UploadManager::on(AdcCommand::GET, UserConnection* aSource, const AdcComman
     catch ( ... ) {}
 }
 
-void UploadManager::on(UserConnectionListener::BytesSent, UserConnection* aSource, size_t aBytes, size_t aActual) throw() {
+void UploadManager::on(UserConnectionListener::BytesSent, UserConnection* aSource, size_t aBytes, size_t aActual) noexcept {
     dcassert(aSource->getState() == UserConnection::STATE_RUNNING);
     Upload* u = aSource->getUpload();
     dcassert(u != NULL);
@@ -421,7 +420,7 @@ void UploadManager::on(UserConnectionListener::BytesSent, UserConnection* aSourc
     u->tick();
 }
 
-void UploadManager::on(UserConnectionListener::Failed, UserConnection* aSource, const string& aError) throw() {
+void UploadManager::on(UserConnectionListener::Failed, UserConnection* aSource, const string& aError) noexcept {
     Upload* u = aSource->getUpload();
 
     if(u) {
@@ -434,7 +433,7 @@ void UploadManager::on(UserConnectionListener::Failed, UserConnection* aSource,
     removeConnection(aSource);
 }
 
-void UploadManager::on(UserConnectionListener::TransmitDone, UserConnection* aSource) throw() {
+void UploadManager::on(UserConnectionListener::TransmitDone, UserConnection* aSource) noexcept {
     dcassert(aSource->getState() == UserConnection::STATE_RUNNING);
     Upload* u = aSource->getUpload();
     dcassert(u != NULL);
@@ -452,21 +451,21 @@ void UploadManager::on(UserConnectionListener::TransmitDone, UserConnection* aSo
 }
 
 void UploadManager::notifyQueuedUsers() {
-        Lock l(cs);
-        int freeSlots = getFreeSlots()*2;               //because there will be non-connecting users
+    Lock l(cs);
+    int freeSlots = getFreeSlots()*2;               //because there will be non-connecting users
 
-        //while all contacted users may not connect, many probably will; it's fine that the rest are filled with randomly allocated slots
-        while (freeSlots) {
-                //get rid of offline users
-                while (!waitingUsers.empty() && !waitingUsers.front().first.user->isOnline()) waitingUsers.pop_front();
-                if (waitingUsers.empty()) break;                //no users to notify
+    //while all contacted users may not connect, many probably will; it's fine that the rest are filled with randomly allocated slots
+    while (freeSlots) {
+        //get rid of offline users
+        while (!waitingUsers.empty() && !waitingUsers.front().first.user->isOnline()) waitingUsers.pop_front();
+        if (waitingUsers.empty()) break;                //no users to notify
 
-                // FIXME: record and replay a client url hint URL
-                ClientManager::getInstance()->connect(waitingUsers.front().first, Util::toString(Util::rand()));
-                --freeSlots;
+        // FIXME: record and replay a client url hint URL
+        ClientManager::getInstance()->connect(waitingUsers.front().first, Util::toString(Util::rand()));
+        --freeSlots;
 
-                waitingUsers.pop_front();
-        }
+        waitingUsers.pop_front();
+    }
 }
 
 void UploadManager::addFailedUpload(const UserConnection& source, string filename) {
@@ -540,7 +539,7 @@ void UploadManager::reloadRestrictions(){
     limits.RenewList(NULL);
 }
 
-void UploadManager::on(TimerManagerListener::Minute, uint64_t /* aTick */) throw() {
+void UploadManager::on(TimerManagerListener::Minute, uint64_t /* aTick */) noexcept {
     UserList disconnects;
     {
         Lock l(cs);
@@ -589,12 +588,12 @@ void UploadManager::on(TimerManagerListener::Minute, uint64_t /* aTick */) throw
     }
 }
 
-void UploadManager::on(GetListLength, UserConnection* conn) throw() {
+void UploadManager::on(GetListLength, UserConnection* conn) noexcept {
     conn->error("GetListLength not supported");
     conn->disconnect(false);
 }
 
-void UploadManager::on(AdcCommand::GFI, UserConnection* aSource, const AdcCommand& c) throw() {
+void UploadManager::on(AdcCommand::GFI, UserConnection* aSource, const AdcCommand& c) noexcept {
     if(aSource->getState() != UserConnection::STATE_GET) {
         dcdebug("UM::onSend Bad state, ignoring\n");
         return;
@@ -620,7 +619,7 @@ void UploadManager::on(AdcCommand::GFI, UserConnection* aSource, const AdcComman
 }
 
 // TimerManagerListener
-void UploadManager::on(TimerManagerListener::Second, uint64_t) throw() {
+void UploadManager::on(TimerManagerListener::Second, uint64_t) noexcept {
     Lock l(cs);
     UploadList ticks;
 
@@ -634,10 +633,10 @@ void UploadManager::on(TimerManagerListener::Second, uint64_t) throw() {
     if(!uploads.empty())
         fire(UploadManagerListener::Tick(), UploadList(uploads));
 
-		//notifyQueuedUsers();
+        //notifyQueuedUsers();
 }
 
-void UploadManager::on(ClientManagerListener::UserDisconnected, const UserPtr& aUser) throw() {
+void UploadManager::on(ClientManagerListener::UserDisconnected, const UserPtr& aUser) noexcept {
     if(!aUser->isOnline()) {
         clearUserFiles(aUser);
     }
