@@ -13,18 +13,28 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef DCPLUSPLUS_DCPP_UTIL_H
 #define DCPLUSPLUS_DCPP_UTIL_H
 
-#ifndef _WIN32
+#ifdef _WIN32
+# define PATH_SEPARATOR '\\'
+# define PATH_SEPARATOR_STR "\\"
+#else
+# define PATH_SEPARATOR '/'
+# define PATH_SEPARATOR_STR "/"
+#endif
+
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
 #include <stdlib.h>
-#endif
+#include <vector>
+#include <functional>
+#include <algorithm>
+#include <map>
 
 #include "Text.h"
 
@@ -61,7 +71,7 @@ public: TypeTraits<type>::ParameterType get##name2() const { return name; } \
 #define LIT(x) x, (sizeof(x)-1)
 
 /** Evaluates op(pair<T1, T2>.first, compareTo) */
-template<class T1, class T2, class op = equal_to<T1> >
+template<class T1, class T2, class op = std::equal_to<T1> >
 class CompareFirst {
 public:
     CompareFirst(const T1& compareTo) : a(compareTo) { }
@@ -72,7 +82,7 @@ private:
 };
 
 /** Evaluates op(pair<T1, T2>.second, compareTo) */
-template<class T1, class T2, class op = equal_to<T2> >
+template<class T1, class T2, class op = std::equal_to<T2> >
 class CompareSecond {
 public:
     CompareSecond(const T2& compareTo) : a(compareTo) { }
@@ -203,7 +213,7 @@ public:
     }
 
     static void decodeUrl(const string& aUrl, string& protocol, string& host, uint16_t& port, string& path, string& query, string& fragment);
-    static map<string, string> decodeQuery(const string& query);
+    static std::map<string, string> decodeQuery(const string& query);
     static string validateFileName(string aFile);
     static bool checkExtension(const string& tmp);
     static string cleanPathChars(string aNick);
@@ -252,7 +262,11 @@ public:
 #ifdef _WIN32
         return _atoi64(aString.c_str());
 #else
+    #ifndef __HAIKU__
+        return strtoq(aString.c_str(), (char **)NULL, 10);
+    #else
         return strtoll(aString.c_str(), (char **)NULL, 10);
+    #endif
 #endif
     }
 
@@ -279,10 +293,10 @@ public:
 
     static unsigned toUInt(const string& s) {
         if(s.empty())
-                return 0;
+            return 0;
         int ret = toInt(s);
         if(ret < 0)
-                return 0;
+            return 0;
         return ret;
     }
 
@@ -349,17 +363,17 @@ public:
     }
 
     template<typename string_t>
-    static string_t toString(const string_t& sep, const vector<string_t>& lst) {
+    static string_t toString(const string_t& sep, const std::vector<string_t>& lst) {
         string_t ret;
-        for(typename vector<string_t>::const_iterator i = lst.begin(), iend = lst.end(); i != iend; ++i) {
+        for(typename std::vector<string_t>::const_iterator i = lst.begin(), iend = lst.end(); i != iend; ++i) {
             ret += *i;
             if(i + 1 != iend)
                 ret += sep;
-    }
-            return ret;
+        }
+        return ret;
     }
     template<typename string_t>
-    static inline string_t toString(const typename string_t::value_type* sep, const vector<string_t>& lst) {
+    static inline string_t toString(const typename string_t::value_type* sep, const std::vector<string_t>& lst) {
         return toString(string_t(sep), lst);
     }
     static string toString(const string& sep, const StringList& lst);
@@ -379,7 +393,7 @@ public:
     template<typename T>
     static T& intersect(T& t1, const T& t2) {
         for(typename T::iterator i = t1.begin(); i != t1.end();) {
-            if(find_if(t2.begin(), t2.end(), bind1st(equal_to<typename T::value_type>(), *i)) == t2.end())
+            if(std::find_if(t2.begin(), t2.end(), bind1st(std::equal_to<typename T::value_type>(), *i)) == t2.end())
                 i = t1.erase(i);
             else
                 ++i;
@@ -389,14 +403,15 @@ public:
 
     static string encodeURI(const string& /*aString*/, bool reverse = false);
     static string getLocalIp();
+    static std::vector<string> getLocalIPs();
     static bool isPrivateIp(string const& ip);
     static string formatAdditionalInfo(const std::string& aIp, bool sIp, bool sCC);
     /**
      * Case insensitive substring search.
      * @return First position found or string::npos
      */
-    static string::size_type findSubString(const string& aString, const string& aSubString, string::size_type start = 0) throw();
-    static wstring::size_type findSubString(const wstring& aString, const wstring& aSubString, wstring::size_type start = 0) throw();
+    static string::size_type findSubString(const string& aString, const string& aSubString, string::size_type start = 0) noexcept;
+    static wstring::size_type findSubString(const wstring& aString, const wstring& aSubString, wstring::size_type start = 0) noexcept;
 
     /* Utf-8 versions of strnicmp and stricmp, unicode char code order (!) */
     static int stricmp(const char* a, const char* b);
@@ -460,7 +475,7 @@ private:
     static string awayMsg;
     static time_t awayTime;
     static time_t startTime;
-    typedef map<uint32_t, uint16_t> CountryList;
+    typedef std::map<uint32_t, uint16_t> CountryList;
     typedef CountryList::iterator CountryIter;
 
     static CountryList countries;
