@@ -28,7 +28,7 @@ using namespace std;
 using namespace dcpp;
 
 FavoriteHubs::FavoriteHubs():
-	BookEntry(Entry::FAVORITE_HUBS, _("Favorite Hubs"), "favoritehubs.glade")
+	BookEntry(Entry::FAVORITE_HUBS, _("Favorite Hubs"), "favoritehubs.ui")
 {
 	// Configure the dialog
 	gtk_dialog_set_alternative_button_order(GTK_DIALOG(getWidget("favoriteHubsDialog")), GTK_RESPONSE_OK, GTK_RESPONSE_CANCEL, -1);
@@ -45,8 +45,12 @@ FavoriteHubs::FavoriteHubs():
 	// Fill the charset drop-down list in edit fav hub dialog.
 	vector<string> &charsets = WulforUtil::getCharsets();
 	for (vector<string>::const_iterator it = charsets.begin(); it != charsets.end(); ++it)
-		gtk_combo_box_append_text(GTK_COMBO_BOX(getWidget("comboboxCharset")), it->c_str());
-	
+#if (((GTK_MAJOR_VERSION == 2) && (GTK_MINOR_VERSION >= 24)) || GTK_MAJOR_VERSION > 2)
+        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(getWidget("comboboxCharset")), it->c_str());
+#else
+        gtk_combo_box_append_text(GTK_COMBO_BOX(getWidget("comboboxCharset")), it->c_str());
+#endif
+
 	// Initialize favorite hub list treeview
 	favoriteView.setView(GTK_TREE_VIEW(getWidget("favoriteView")), TRUE, "favoritehubs");
 	favoriteView.insertColumn(_("Auto Connect"), G_TYPE_BOOLEAN, TreeView::BOOL, 100);
@@ -66,7 +70,7 @@ FavoriteHubs::FavoriteHubs():
 	g_object_unref(favoriteStore);
 	gtk_tree_view_set_fixed_height_mode(favoriteView.get(), TRUE);
 	favoriteSelection = gtk_tree_view_get_selection(favoriteView.get());
-	GList *list = gtk_tree_view_column_get_cell_renderers(gtk_tree_view_get_column(favoriteView.get(), favoriteView.col(_("Auto Connect"))));
+	GList *list = gtk_cell_layout_get_cells(GTK_CELL_LAYOUT(gtk_tree_view_get_column(favoriteView.get(), favoriteView.col(_("Auto Connect")))));
 	GtkCellRenderer *renderer = (GtkCellRenderer *)g_list_nth_data(list, 0);
 	g_list_free(list);
 
@@ -236,14 +240,9 @@ gboolean FavoriteHubs::onKeyReleased_gui(GtkWidget *widget, GdkEventKey *event,
 
 		if (event->keyval == GDK_Return || event->keyval == GDK_KP_Enter)
 		{
-			GtkTreeViewColumn *column;
-			gtk_tree_view_get_cursor(fh->favoriteView.get(), NULL, &column);
-			if (column && column != gtk_tree_view_get_column(fh->favoriteView.get(), fh->favoriteView.col(_("Auto Connect"))))
-			{
-				WulforManager::get()->getMainWindow()->showHub_gui(
-					fh->favoriteView.getString(&iter, _("Address")),
-					fh->favoriteView.getString(&iter, _("Encoding")));
-			}
+			WulforManager::get()->getMainWindow()->showHub_gui(
+				fh->favoriteView.getString(&iter, _("Address")),
+				fh->favoriteView.getString(&iter, _("Encoding")));
 		}
 		else if (event->keyval == GDK_Delete || event->keyval == GDK_BackSpace)
 		{
@@ -366,11 +365,15 @@ bool FavoriteHubs::showFavoriteHubDialog_gui(StringMap &params, FavoriteHubs *fh
 
 		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fh->getWidget("checkbuttonEncoding"))))
 		{
-			gchar *encoding = gtk_combo_box_get_active_text(GTK_COMBO_BOX(fh->getWidget("comboboxCharset")));
+#if (((GTK_MAJOR_VERSION == 2) && (GTK_MINOR_VERSION >= 24)) || GTK_MAJOR_VERSION > 2)
+            gchar *encoding = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(fh->getWidget("comboboxCharset")));
+#else
+            gchar *encoding = gtk_combo_box_get_active_text(GTK_COMBO_BOX(fh->getWidget("comboboxCharset")));
+#endif
 			params["Encoding"] = string(encoding);
 			g_free(encoding);
 		}
-		
+
 		{
 			params["Mode"] = Util::toString(gtk_combo_box_get_active(GTK_COMBO_BOX(fh->getWidget("comboboxMode"))));
 			params["Search Interval"] = Util::toString(gtk_spin_button_get_value(GTK_SPIN_BUTTON(fh->getWidget("spinButton_MINSEARCH_INTERVAL"))));
@@ -583,7 +586,7 @@ void FavoriteHubs::setConnect_client(string address, bool active)
 	}
 }
 
-void FavoriteHubs::on(FavoriteManagerListener::FavoriteAdded, const FavoriteHubEntryPtr entry) throw()
+void FavoriteHubs::on(FavoriteManagerListener::FavoriteAdded, const FavoriteHubEntryPtr entry) noexcept
 {
 	StringMap params;
 	getFavHubParams_client(entry, params);
@@ -593,10 +596,9 @@ void FavoriteHubs::on(FavoriteManagerListener::FavoriteAdded, const FavoriteHubE
 	WulforManager::get()->dispatchGuiFunc(func);
 }
 
-void FavoriteHubs::on(FavoriteManagerListener::FavoriteRemoved, const FavoriteHubEntryPtr entry) throw()
+void FavoriteHubs::on(FavoriteManagerListener::FavoriteRemoved, const FavoriteHubEntryPtr entry) noexcept
 {
 	typedef Func1<FavoriteHubs, string> F1;
 	F1 *func = new F1(this, &FavoriteHubs::removeEntry_gui, entry->getServer());
 	WulforManager::get()->dispatchGuiFunc(func);
 }
-
