@@ -36,7 +36,7 @@ using namespace std;
 using namespace dcpp;
 
 PrivateMessage::PrivateMessage(const string &cid, const string &hubUrl):
-    BookEntry(Entry::PRIVATE_MESSAGE, WulforUtil::getNicks(cid, hubUrl), "privatemessage.glade", cid),
+    BookEntry(Entry::PRIVATE_MESSAGE, WulforUtil::getNicks(cid, hubUrl), "privatemessage.ui", cid),
     cid(cid),
     hubUrl(hubUrl),
     historyIndex(0),
@@ -256,10 +256,10 @@ void PrivateMessage::preferences_gui()
 
     if (!WGETB("emoticons-use"))
     {
-        if (GTK_WIDGET_IS_SENSITIVE(getWidget("emotButton")))
+        if (gtk_widget_is_sensitive(getWidget("emotButton")))
             gtk_widget_set_sensitive(getWidget("emotButton"), FALSE);
     }
-    else if (!GTK_WIDGET_IS_SENSITIVE(getWidget("emotButton")))
+    else if (!gtk_widget_is_sensitive(getWidget("emotButton")))
     {
         gtk_widget_set_sensitive(getWidget("emotButton"), TRUE);
     }
@@ -1381,7 +1381,7 @@ void PrivateMessage::grantSlot_client()
     }
 }
 
-void PrivateMessage::on(ClientManagerListener::UserConnected, const UserPtr& aUser) throw()
+void PrivateMessage::on(ClientManagerListener::UserConnected, const UserPtr& aUser) noexcept
 {
         if (aUser->getCID() == CID(cid))
         {
@@ -1391,7 +1391,7 @@ void PrivateMessage::on(ClientManagerListener::UserConnected, const UserPtr& aUs
         }
 }
 
-void PrivateMessage::on(ClientManagerListener::UserDisconnected, const UserPtr& aUser) throw()
+void PrivateMessage::on(ClientManagerListener::UserDisconnected, const UserPtr& aUser) noexcept
 {
         if (aUser->getCID() == CID(cid))
         {
