@@ -38,7 +38,7 @@ using namespace dcpp;
 GtkTreeModel* Search::searchEntriesModel = NULL;
 
 Search::Search():
-    BookEntry(Entry::SEARCH, _("Search"), "search.glade", generateID()),
+    BookEntry(Entry::SEARCH, _("Search"), "search.ui", generateID()),
     previousGrouping(NOGROUPING)
 {
     // Initialize the search entries combo box
@@ -77,7 +77,7 @@ Search::Search():
     gtk_tree_view_set_model(hubView.get(), GTK_TREE_MODEL(hubStore));
     g_object_unref(hubStore);
     GtkTreeViewColumn *col = gtk_tree_view_get_column(hubView.get(), hubView.col(_("Search")));
-    GList *list = gtk_tree_view_column_get_cell_renderers(col);
+    GList *list = gtk_cell_layout_get_cells(GTK_CELL_LAYOUT(col));
     GtkCellRenderer *renderer = (GtkCellRenderer *)g_list_nth_data(list, 0);
     g_list_free(list);
 
@@ -162,6 +162,7 @@ Search::Search():
     g_signal_connect(resultView.get(), "key-release-event", G_CALLBACK(onKeyReleased_gui), (gpointer)this);
     g_signal_connect(searchEntry, "key-press-event", G_CALLBACK(onSearchEntryKeyPressed_gui), (gpointer)this);
     g_signal_connect(searchEntry, "key-release-event", G_CALLBACK(onKeyReleased_gui), (gpointer)this);
+    g_signal_connect(getWidget("entrySize"), "key-press-event", G_CALLBACK(onSearchEntryKeyPressed_gui), (gpointer)this);
     g_signal_connect(getWidget("entrySize"), "key-release-event", G_CALLBACK(onKeyReleased_gui), (gpointer)this);
     g_signal_connect(getWidget("buttonSearch"), "clicked", G_CALLBACK(onSearchButtonClicked_gui), (gpointer)this);
     g_signal_connect(getWidget("downloadItem"), "activate", G_CALLBACK(onDownloadClicked_gui), (gpointer)this);
@@ -433,8 +434,10 @@ void Search::search_gui()
         valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(hubStore), &iter);
     }
 
+#ifndef WITH_DHT
     if (clients.size() < 1)
         return;
+#endif
 
     double lsize = Util::toDouble(gtk_entry_get_text(GTK_ENTRY(getWidget("entrySize"))));
 
@@ -477,10 +480,14 @@ void Search::search_gui()
         }
         else
         {
-                gchar *tmp = gtk_combo_box_get_active_text(GTK_COMBO_BOX(getWidget("comboboxFile")));
-                ftypeStr = tmp;
-                g_free(tmp);
-                ftype = SearchManager::TYPE_ANY;
+#if (((GTK_MAJOR_VERSION == 2) && (GTK_MINOR_VERSION >= 24)) || GTK_MAJOR_VERSION > 2)
+            gchar *tmp = g_strdup(gtk_entry_get_text (GTK_ENTRY(gtk_bin_get_child(GTK_BIN((GTK_COMBO_BOX(getWidget("comboboxFile"))))))));
+#else
+            gchar *tmp = gtk_combo_box_get_active_text(GTK_COMBO_BOX(getWidget("comboboxFile")));
+#endif
+            ftypeStr = tmp;
+            g_free(tmp);
+            ftype = SearchManager::TYPE_ANY;
         }
 
         // Get ADC searchtype extensions if any is selected
@@ -656,7 +663,7 @@ void Search::updateParentRow_gui(GtkTreeIter *parent, GtkTreeIter *child)
     dcassert(children != 0);
 
     string users = Util::toString(children) + _(" user(s)");
-    gtk_tree_store_set(resultStore, parent, resultView.col("Nick"), users.c_str(), -1);
+    gtk_tree_store_set(resultStore, parent, resultView.col(_("Nick")), users.c_str(), -1);
 
     if (child == NULL)
         return;
@@ -669,110 +676,36 @@ void Search::updateParentRow_gui(GtkTreeIter *parent, GtkTreeIter *child)
             break;
         case FILENAME:
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("File Order"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Path")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Exact Size")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Size")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Real Size"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Connection")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("TTH")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Nick")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Hub")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Hub URL"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Type")));
             break;
         case FILEPATH:
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("File Order"));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Path")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Exact Size")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Size")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Real Size"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Connection")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("TTH")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Nick")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Hub")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Hub URL"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Type")));
             break;
         case SIZE:
         {
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("File Order"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Path")));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Exact Size")));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Size")));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Real Size"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Connection")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("TTH")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Nick")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Hub")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Hub URL"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Type")));
             break;
         }
         case CONNECTION:
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("File Order"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Path")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Exact Size")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Size")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Real Size"));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Connection")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("TTH")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Nick")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Hub")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Hub URL"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Type")));
             break;
         case TTH:
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("File Order"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Path")));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Exact Size")));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Size")));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Real Size"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Connection")));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("TTH")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Nick")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Hub")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Hub URL"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Type")));
             break;
         case NICK:
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("File Order"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Path")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Exact Size")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Size")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Real Size"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Connection")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("TTH")));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Nick")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Hub")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Hub URL"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Type")));
             break;
         case HUB:
         {
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("File Order"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Path")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Exact Size")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Size")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Real Size"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Connection")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("TTH")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Nick")));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Hub")));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Hub URL"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Type")));
             break;
         }
         case TYPE:
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("File Order"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Path")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Exact Size")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Size")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Real Size"));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Connection")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("TTH")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Nick")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Hub")));
-            WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col("Hub URL"));
             WulforUtil::copyValue_gui(resultStore, child, parent, resultView.col(_("Type")));;
             break;
         default:
@@ -1853,7 +1786,7 @@ void Search::removeSource_client(string cid)
     }
 }
 
-void Search::on(ClientManagerListener::ClientConnected, Client *client) throw()
+void Search::on(ClientManagerListener::ClientConnected, Client *client) noexcept
 {
     if (client)
     {
@@ -1863,7 +1796,7 @@ void Search::on(ClientManagerListener::ClientConnected, Client *client) throw()
     }
 }
 
-void Search::on(ClientManagerListener::ClientUpdated, Client *client) throw()
+void Search::on(ClientManagerListener::ClientUpdated, Client *client) noexcept
 {
     if (client)
     {
@@ -1873,7 +1806,7 @@ void Search::on(ClientManagerListener::ClientUpdated, Client *client) throw()
     }
 }
 
-void Search::on(ClientManagerListener::ClientDisconnected, Client *client) throw()
+void Search::on(ClientManagerListener::ClientDisconnected, Client *client) noexcept
 {
     if (client)
     {
@@ -1883,7 +1816,7 @@ void Search::on(ClientManagerListener::ClientDisconnected, Client *client) throw
     }
 }
 
-void Search::on(SearchManagerListener::SR, const SearchResultPtr& result) throw()
+void Search::on(SearchManagerListener::SR, const SearchResultPtr& result) noexcept
 {
     if (searchlist.empty() || result == NULL)
         return;
