@@ -40,7 +40,7 @@ using namespace std;
 using namespace dcpp;
 
 Transfers::Transfers() :
-    Entry(Entry::TRANSFERS, "transfers.glade")
+    Entry(Entry::TRANSFERS, "transfers.ui")
 {
     // menu
     g_object_ref_sink(getWidget("transferMenu"));
@@ -63,6 +63,7 @@ Transfers::Transfers() :
     transferView.insertColumn(_("Size"), G_TYPE_INT64, TreeView::SIZE, 125);
     transferView.insertColumn(_("Path"), G_TYPE_STRING, TreeView::STRING, 200);
     transferView.insertColumn(_("IP"), G_TYPE_STRING, TreeView::STRING, 175);
+    transferView.insertColumn(_("Encryption"), G_TYPE_STRING, TreeView::STRING, 175);
     transferView.insertHiddenColumn("Icon", G_TYPE_STRING);
     transferView.insertHiddenColumn("Progress", G_TYPE_INT);
     transferView.insertHiddenColumn("Sort Order", G_TYPE_STRING);
@@ -887,9 +888,10 @@ void Transfers::getParams_client(StringMap& params, Transfer* tr)
     params["Time Left"] = tr->getSecondsLeft() > 0 ? Util::toString(tr->getSecondsLeft()) : "-1";
     params["Target"] = tr->getPath();
     params["Hub URL"] = tr->getUserConnection().getHubUrl();
+    params["Encryption"] = tr->getUserConnection().isSecure() ? tr->getUserConnection().getCipherName() : _("Plain");
 }
 
-void Transfers::on(DownloadManagerListener::Requesting, Download* dl) throw()
+void Transfers::on(DownloadManagerListener::Requesting, Download* dl) noexcept
 {
     StringMap params;
 
@@ -906,7 +908,7 @@ void Transfers::on(DownloadManagerListener::Requesting, Download* dl) throw()
     WulforManager::get()->dispatchGuiFunc(f1);
 }
 
-void Transfers::on(DownloadManagerListener::Starting, Download* dl) throw()
+void Transfers::on(DownloadManagerListener::Starting, Download* dl) noexcept
 {
     StringMap params;
 
@@ -921,7 +923,7 @@ void Transfers::on(DownloadManagerListener::Starting, Download* dl) throw()
     WulforManager::get()->dispatchGuiFunc(f3);
 }
 
-void Transfers::on(DownloadManagerListener::Tick, const DownloadList& dls) throw()
+void Transfers::on(DownloadManagerListener::Tick, const DownloadList& dls) noexcept
 {
     for (DownloadList::const_iterator it = dls.begin(); it != dls.end(); ++it)
     {
@@ -954,7 +956,7 @@ void Transfers::on(DownloadManagerListener::Tick, const DownloadList& dls) throw
     }
 }
 
-void Transfers::on(DownloadManagerListener::Complete, Download* dl) throw()
+void Transfers::on(DownloadManagerListener::Complete, Download* dl) noexcept
 {
     StringMap params;
 
@@ -974,12 +976,12 @@ void Transfers::on(DownloadManagerListener::Complete, Download* dl) throw()
     WulforManager::get()->dispatchGuiFunc(f2b);
 }
 
-void Transfers::on(DownloadManagerListener::Failed, Download* dl, const string& reason) throw()
+void Transfers::on(DownloadManagerListener::Failed, Download* dl, const string& reason) noexcept
 {
     onFailed(dl, reason);
 }
 
-void Transfers::on(QueueManagerListener::CRCFailed, Download* dl, const string& reason) throw()
+void Transfers::on(QueueManagerListener::CRCFailed, Download* dl, const string& reason) noexcept
 {
     onFailed(dl, reason);
 }
@@ -1004,7 +1006,7 @@ void Transfers::onFailed(Download* dl, const string& reason) {
     WulforManager::get()->dispatchGuiFunc(f2b);
 }
 
-void Transfers::on(ConnectionManagerListener::Added, ConnectionQueueItem* cqi) throw()
+void Transfers::on(ConnectionManagerListener::Added, ConnectionQueueItem* cqi) noexcept
 {
     StringMap params;
     getParams_client(params, cqi);
@@ -1015,7 +1017,7 @@ void Transfers::on(ConnectionManagerListener::Added, ConnectionQueueItem* cqi) t
     WulforManager::get()->dispatchGuiFunc(f2);
 }
 
-void Transfers::on(ConnectionManagerListener::Connected, ConnectionQueueItem* cqi) throw()
+void Transfers::on(ConnectionManagerListener::Connected, ConnectionQueueItem* cqi) noexcept
 {
     StringMap params;
     getParams_client(params, cqi);
@@ -1026,7 +1028,7 @@ void Transfers::on(ConnectionManagerListener::Connected, ConnectionQueueItem* cq
     WulforManager::get()->dispatchGuiFunc(f3);
 }
 
-void Transfers::on(ConnectionManagerListener::Removed, ConnectionQueueItem* cqi) throw()
+void Transfers::on(ConnectionManagerListener::Removed, ConnectionQueueItem* cqi) noexcept
 {
     string cid = cqi->getUser().user->getCID().toBase32();//NOTE: core 0.762
     typedef Func2<Transfers, const string, bool> F2;
@@ -1034,7 +1036,7 @@ void Transfers::on(ConnectionManagerListener::Removed, ConnectionQueueItem* cqi)
     WulforManager::get()->dispatchGuiFunc(f2);
 }
 
-void Transfers::on(ConnectionManagerListener::Failed, ConnectionQueueItem* cqi, const string& reason) throw()
+void Transfers::on(ConnectionManagerListener::Failed, ConnectionQueueItem* cqi, const string& reason) noexcept
 {
     StringMap params;
     getParams_client(params, cqi);
@@ -1049,7 +1051,7 @@ void Transfers::on(ConnectionManagerListener::Failed, ConnectionQueueItem* cqi,
     WulforManager::get()->dispatchGuiFunc(f3);
 }
 
-void Transfers::on(ConnectionManagerListener::StatusChanged, ConnectionQueueItem* cqi) throw()
+void Transfers::on(ConnectionManagerListener::StatusChanged, ConnectionQueueItem* cqi) noexcept
 {
     StringMap params;
     getParams_client(params, cqi);
@@ -1065,7 +1067,7 @@ void Transfers::on(ConnectionManagerListener::StatusChanged, ConnectionQueueItem
     WulforManager::get()->dispatchGuiFunc(f3);
 }
 
-void Transfers::on(QueueManagerListener::Finished, QueueItem* qi, const string& dir, int64_t size) throw()
+void Transfers::on(QueueManagerListener::Finished, QueueItem* qi, const string& dir, int64_t size) noexcept
 {
     string target = qi->getTarget();
     Sound::TypeSound sound = Sound::DOWNLOAD_FINISHED;
@@ -1084,7 +1086,7 @@ void Transfers::on(QueueManagerListener::Finished, QueueItem* qi, const string&
     WulforManager::get()->dispatchGuiFunc(f3);
 }
 
-void Transfers::on(QueueManagerListener::Removed, QueueItem* qi) throw()
+void Transfers::on(QueueManagerListener::Removed, QueueItem* qi) noexcept
 {
     string target = qi->getTarget();
 
@@ -1093,7 +1095,7 @@ void Transfers::on(QueueManagerListener::Removed, QueueItem* qi) throw()
     WulforManager::get()->dispatchGuiFunc(f3);
 }
 
-void Transfers::on(UploadManagerListener::Starting, Upload* ul) throw()
+void Transfers::on(UploadManagerListener::Starting, Upload* ul) noexcept
 {
     StringMap params;
 
@@ -1108,7 +1110,7 @@ void Transfers::on(UploadManagerListener::Starting, Upload* ul) throw()
     WulforManager::get()->dispatchGuiFunc(f3);
 }
 
-void Transfers::on(UploadManagerListener::Tick, const UploadList& uls) throw()
+void Transfers::on(UploadManagerListener::Tick, const UploadList& uls) noexcept
 {
     for (UploadList::const_iterator it = uls.begin(); it != uls.end(); ++it)
     {
@@ -1139,7 +1141,7 @@ void Transfers::on(UploadManagerListener::Tick, const UploadList& uls) throw()
     }
 }
 
-void Transfers::on(UploadManagerListener::Complete, Upload* ul) throw()
+void Transfers::on(UploadManagerListener::Complete, Upload* ul) noexcept
 {
     StringMap params;
 
@@ -1153,7 +1155,7 @@ void Transfers::on(UploadManagerListener::Complete, Upload* ul) throw()
     WulforManager::get()->dispatchGuiFunc(f3);
 }
 
-void Transfers::on(UploadManagerListener::Failed, Upload* ul, const string& reason) throw()
+void Transfers::on(UploadManagerListener::Failed, Upload* ul, const string& reason) noexcept
 {
     StringMap params;
     getParams_client(params, ul);
