@@ -26,7 +26,6 @@
 #endif
 
 #include "dcpp/stdinc.h"
-#include "dcpp/DCPlusPlus.h"
 #include "dcpp/FinishedManager.h"
 //#include "dcpp/FinishedManagerListener.h"
 #include "dcpp/Util.h"
@@ -216,7 +215,7 @@ private:
             model->addUser(params);;
         }
 
-        FinishedManager::getInstance()->unLockLists();
+        FinishedManager::getInstance()->unlockLists();
 
         AsyncRunner *runner = new AsyncRunner(this);
         boost::function<void()> f = boost::bind(&FinishedTransfers<isUpload>::loadListFromDB, this);
@@ -511,7 +510,7 @@ private:
             retranslateUi(this);
     }
 
-    void on(FinishedManagerListener::AddedFile, bool upload, const std::string &file, const FinishedFileItemPtr &item) throw(){
+    void on(FinishedManagerListener::AddedFile, bool upload, const std::string &file, const FinishedFileItemPtr &item) noexcept{
         if (isUpload == upload){
             VarMap params;
 
@@ -521,7 +520,7 @@ private:
         }
     }
 
-    void on(FinishedManagerListener::AddedUser, bool upload, const dcpp::HintedUser &user, const FinishedUserItemPtr &item) throw(){
+    void on(FinishedManagerListener::AddedUser, bool upload, const dcpp::HintedUser &user, const FinishedUserItemPtr &item) noexcept{
         if (isUpload == upload){
             VarMap params;
 
@@ -531,7 +530,7 @@ private:
         }
     }
 
-    void on(FinishedManagerListener::UpdatedFile, bool upload, const std::string &file, const FinishedFileItemPtr &item) throw(){
+    void on(FinishedManagerListener::UpdatedFile, bool upload, const std::string &file, const FinishedFileItemPtr &item) noexcept{
         if (isUpload == upload){
             VarMap params;
 
@@ -541,13 +540,13 @@ private:
         }
     }
 
-    void on(FinishedManagerListener::RemovedFile, bool upload, const std::string &file) throw(){
+    void on(FinishedManagerListener::RemovedFile, bool upload, const std::string &file) noexcept{
         if (isUpload == upload){
             emit coreRemovedFile(_q(file));
         }
     }
 
-    void on(FinishedManagerListener::UpdatedUser, bool upload, const dcpp::HintedUser &user) throw(){
+    void on(FinishedManagerListener::UpdatedUser, bool upload, const dcpp::HintedUser &user) noexcept{
         if (isUpload == upload){
             const FinishedManager::MapByUser &umap = FinishedManager::getInstance()->getMapByUser(isUpload);
             FinishedManager::MapByUser::const_iterator userit = umap.find(user);
@@ -564,7 +563,7 @@ private:
         }
     }
 
-    void on(FinishedManagerListener::RemovedUser, bool upload, const dcpp::HintedUser &user) throw(){
+    void on(FinishedManagerListener::RemovedUser, bool upload, const dcpp::HintedUser &user) noexcept{
         if (isUpload == upload){
             emit coreRemovedUser(_q(user.user->getCID().toBase32()));
         }
