@@ -328,7 +328,8 @@ SearchFrame::SearchFrame(QWidget *parent):
         timer1(NULL),
         saveFileType(true),
         proxy(NULL),
-        completer(NULL)
+        completer(NULL),
+        stop(false)
 {
     if (!SearchBlacklist::getInstance())
         SearchBlacklist::newInstance();
@@ -419,6 +420,8 @@ void SearchFrame::init(){
 
     frame_FILTER->setVisible(false);
 
+    pushButton_STOP->hide();
+
     toolButton_CLOSEFILTER->setIcon(WICON(WulforUtil::eiEDITDELETE));
 
     treeView_RESULTS->setModel(model);
@@ -484,6 +487,7 @@ void SearchFrame::init(){
     connect(focusShortcut, SIGNAL(activated()), lineEdit_SEARCHSTR, SLOT(selectAll()));
     connect(close_wnd, SIGNAL(triggered()), this, SLOT(close()));
     connect(pushButton_SEARCH, SIGNAL(clicked()), this, SLOT(slotStartSearch()));
+    connect(pushButton_STOP, SIGNAL(clicked()), this, SLOT(slotStopSearch()));
     connect(pushButton_CLEAR, SIGNAL(clicked()), this, SLOT(slotClear()));
     connect(treeView_RESULTS, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(slotResultDoubleClicked(QModelIndex)));
     connect(treeView_RESULTS, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotContextMenu(QPoint)));
@@ -491,6 +495,7 @@ void SearchFrame::init(){
     connect(timer1, SIGNAL(timeout()), this, SLOT(slotTimer()));
     connect(pushButton_SIDEPANEL, SIGNAL(clicked()), this, SLOT(slotToggleSidePanel()));
     connect(lineEdit_SEARCHSTR, SIGNAL(returnPressed()), this, SLOT(slotStartSearch()));
+	connect(lineEdit_SIZE,      SIGNAL(returnPressed()), this, SLOT(slotStartSearch()));
     connect(comboBox_FILETYPES, SIGNAL(currentIndexChanged(int)), lineEdit_SEARCHSTR, SLOT(setFocus()));
     connect(comboBox_FILETYPES, SIGNAL(currentIndexChanged(int)), lineEdit_SEARCHSTR, SLOT(selectAll()));
     connect(toolButton_CLOSEFILTER, SIGNAL(clicked()), this, SLOT(slotFilter()));
@@ -875,6 +880,14 @@ void SearchFrame::fastSearch(const QString &text, bool isTTH){
 }
 
 void SearchFrame::slotStartSearch(){
+    if (qobject_cast<QPushButton*>(sender()) != pushButton_SEARCH){
+        pushButton_SEARCH->click(); //Generating clicked() signal that shows pushButton_STOP button.
+                                    //Anybody can suggest something better?
+        return;
+    }
+
+    stop=false;
+
     if (lineEdit_SEARCHSTR->text().trimmed().isEmpty())
         return;
 
@@ -889,8 +902,10 @@ void SearchFrame::slotStartSearch(){
             clients.push_back(_tq(index.data().toString()));
     }
 
+#ifndef WITH_DHT
     if (clients.empty())
         return;
+#endif
 
     QString str_size = lineEdit_SIZE->text();
     double lsize = Util::toDouble(Text::fromT(str_size.toStdString()));
@@ -1546,8 +1561,8 @@ void SearchFrame::slotSettingsChanged(const QString &key, const QString &value){
         retranslateUi(this);
 }
 
-void SearchFrame::on(SearchManagerListener::SR, const dcpp::SearchResultPtr& aResult) throw() {
-    if (currentSearch.empty() || aResult == NULL)
+void SearchFrame::on(SearchManagerListener::SR, const dcpp::SearchResultPtr& aResult) noexcept {
+    if (currentSearch.empty() || aResult == NULL || stop == true)
         return;
 
     if (!aResult->getToken().empty() && token != _q(aResult->getToken())){
@@ -1598,14 +1613,17 @@ void SearchFrame::on(SearchManagerListener::SR, const dcpp::SearchResultPtr& aRe
     emit coreSR(map);
 }
 
-void SearchFrame::on(ClientConnected, Client* c) throw(){
+void SearchFrame::on(ClientConnected, Client* c) noexcept{
     emit coreClientConnected(_q(c->getHubUrl()));
 }
 
-void SearchFrame::on(ClientUpdated, Client* c) throw(){
+void SearchFrame::on(ClientUpdated, Client* c) noexcept{
     emit coreClientUpdated((_q(c->getHubUrl())));
 }
 
-void SearchFrame::on(ClientDisconnected, Client* c) throw(){
+void SearchFrame::on(ClientDisconnected, Client* c) noexcept{
     emit coreClientDisconnected((_q(c->getHubUrl())));
 }
+void SearchFrame::slotStopSearch(){
+    stop = true;
+}
