@@ -217,9 +217,16 @@ ShareBrowser::ShareBrowser(UserPtr user, QString file, QString jump_to):
             title = tr("Listing: ") + nick;
     }
 
-    init();
-
     setAttribute(Qt::WA_DeleteOnClose);
+
+    AsyncRunner *runner = new AsyncRunner(this);
+    boost::function<void()> f = boost::bind(&ShareBrowser::buildList, this);
+
+    runner->setRunFunction(f);
+    connect(runner, SIGNAL(finished()), this, SLOT(init()), Qt::QueuedConnection);
+    connect(runner, SIGNAL(finished()), runner, SLOT(deleteLater()), Qt::QueuedConnection);
+
+    runner->start();
 }
 
 ShareBrowser::~ShareBrowser(){
@@ -277,8 +284,6 @@ void ShareBrowser::init(){
 
     initModels();
 
-    buildList();
-
     lineEdit_FILTER->installEventFilter(this);
 
     treeView_LPANE->setModel(tree_model);
@@ -316,9 +321,39 @@ void ShareBrowser::init(){
     connect(WulforSettings::getInstance(), SIGNAL(strValueChanged(QString,QString)), this, SLOT(slotSettingsChanged(QString,QString)));
     connect(toolButton_SEARCH, SIGNAL(clicked()), this, SLOT(slotStartSearch()));
 
-    setAttribute(Qt::WA_DeleteOnClose);
+    continueInit();
 }
 
+void ShareBrowser::continueInit(){
+    tree_model->repaint();
+    list_model->repaint();
+
+    load();
+
+    if (user == ClientManager::getInstance()->getMe())
+        tree_model->loadRestrictions();
+
+    if (!jump_to.isEmpty()){
+        FileBrowserItem *root = tree_model->getRootElem();
+
+        root = root->childItems.at(0);
+
+        FileBrowserItem *jump = tree_model->createRootForPath(jump_to, root);
+
+        if (jump){
+            QModelIndex jump_index = tree_model->createIndexForItem(jump);
+
+            treeView_LPANE->selectionModel()->select(jump_index, QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows);
+            treeView_LPANE->scrollTo(jump_index, QAbstractItemView::PositionAtCenter);
+        }
+    }
+
+    MainWindow::getInstance()->addArenaWidget(this);
+    MainWindow::getInstance()->addArenaWidgetOnToolbar(this);
+    MainWindow::getInstance()->mapWidgetOnArena(this);
+}
+
+
 void ShareBrowser::load(){
     int w = WIGET(WI_SHARE_WIDTH);
     int wr= WIGET(WI_SHARE_RPANE_WIDTH);
@@ -372,18 +407,6 @@ void ShareBrowser::buildList(){
         listing.loadFile(file.toStdString());
         listing.getRoot()->setName(nick.toStdString());
         ADLSearchManager::getInstance()->matchListing(listing);
-
-        AsyncRunner *runner = new AsyncRunner(this);
-        boost::function<void()> f = boost::bind(&ShareBrowser::createTree, this, listing.getRoot(), tree_root);
-
-        runner->setRunFunction(f);
-        connect(runner, SIGNAL(finished()), this, SLOT(slotLoaderFinish()));
-        connect(runner, SIGNAL(finished()), runner, SLOT(deleteLater()));
-
-        runner->start();
-
-        treeView_LPANE->blockSignals(true);
-        treeView_RPANE->blockSignals(true);
     }
     catch (const Exception &e){
         QMessageBox::critical(this, file, _q(e.what()), QMessageBox::Ok);
@@ -392,51 +415,14 @@ void ShareBrowser::buildList(){
     }
 }
 
-void ShareBrowser::createTree(DirectoryListing::Directory *dir, FileBrowserItem *root){
-    if (!(dir && root))
-        return;
-
-    DirectoryListing::Directory::Iter it;
-    FileBrowserItem *item;
-    quint64 size = 0;
-    QList<QVariant> data;
-
-    size = dir->getTotalSize(true);
-
-    data << _q(dir->getName())
-         << WulforUtil::formatBytes(size)
-         << size
-         << "";
-
-    item = new FileBrowserItem(data, root);
-    item->dir = dir;
-
-    root->appendChild(item);
-
-    itemsCount += dir->getFileCount();
-
-    //std::sort(dir->directories.begin(), dir->directories.end(), DirectoryListing::Directory::DirSort());
-
-    for (it = dir->directories.begin(); it != dir->directories.end(); ++it)
-        createTree(*it, item);
-}
-
 void ShareBrowser::initModels(){
     tree_model = new FileBrowserModel();
-    tree_root  = new FileBrowserItem(QList<QVariant>() << tr("") << tr("")
-                                                       << tr("")
-                                                       << tr(""),
-                                                       NULL);
-
-    tree_model->setRootElem(tree_root, true, true);
+    tree_model->setListing(&listing);
+    tree_model->fetchMore(QModelIndex());
+    tree_root  = tree_model->getRootElem();
 
     list_model = new FileBrowserModel();
-    list_root = new FileBrowserItem(QList<QVariant>() << tr("") << tr("")
-                                                      << tr("")
-                                                      << tr(""),
-                                                      NULL);
-
-    list_model->setRootElem(list_root, true, true);
+    list_root = list_model->getRootElem();
 }
 
 void ShareBrowser::goDown(QTreeView *view){
@@ -529,14 +515,21 @@ void ShareBrowser::slotRightPaneClicked(const QModelIndex &index){
         return;
     }
 
-    label_PATH->setText(label_PATH->text()+"\\"+item->data(COLUMN_FILEBROWSER_NAME).toString());
+    QString parent_path = label_PATH->text();
+    QModelIndex parent_index = tree_model->createIndexForItem(tree_model->createRootForPath(parent_path));
 
-    FileBrowserItem *tree_item = tree_model->createRootForPath(label_PATH->text());
+    parent_path = parent_path +"\\"+item->data(COLUMN_FILEBROWSER_NAME).toString();
+    parent_index = tree_model->createIndexForItem(tree_model->createRootForPath(parent_path));
 
-    QModelIndex tree_index = tree_model->createIndexForItem(tree_item);
+    if (!parent_index.isValid())
+        return;
 
-    treeView_LPANE->selectionModel()->select(tree_index, QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows);
-    treeView_LPANE->scrollTo(tree_index, QAbstractItemView::PositionAtCenter);
+    if (tree_model->canFetchMore(parent_index))
+        tree_model->fetchMore(parent_index);
+
+    treeView_LPANE->selectionModel()->clear();
+    treeView_LPANE->selectionModel()->select(parent_index, QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows);
+    treeView_LPANE->scrollTo(parent_index, QAbstractItemView::PositionAtCenter);
 }
 
 void ShareBrowser::changeRoot(dcpp::DirectoryListing::Directory *root){
@@ -921,48 +914,6 @@ void ShareBrowser::slotCustomContextMenu(const QPoint &){
     }
 }
 
-void ShareBrowser::slotLoaderFinish(){
-    treeView_LPANE->blockSignals(false);
-    treeView_RPANE->blockSignals(false);
-
-    tree_model->repaint();
-    list_model->repaint();
-
-    load();
-
-    if (user == ClientManager::getInstance()->getMe())
-        tree_model->loadRestrictions();
-
-    if (!jump_to.isEmpty()){
-        FileBrowserItem *root = tree_model->getRootElem();
-
-        root = root->childItems.at(0);
-
-        FileBrowserItem *jump = tree_model->createRootForPath(jump_to, root);
-
-        if (jump){
-            QModelIndex jump_index = tree_model->createIndexForItem(jump);
-
-            treeView_LPANE->selectionModel()->select(jump_index, QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows);
-            treeView_LPANE->scrollTo(jump_index, QAbstractItemView::PositionAtCenter);
-        }
-    }
-    else {
-        QModelIndex index = tree_model->index(0, 0, QModelIndex());
-
-        treeView_LPANE->selectionModel()->select(index, QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows);
-        treeView_LPANE->expand(index);
-    }
-
-    /*treeView_LPANE->resizeColumnToContents(0);
-    treeView_LPANE->resizeColumnToContents(1);*/
-
-    MainWindow::getInstance()->addArenaWidget(this);
-    MainWindow::getInstance()->addArenaWidgetOnToolbar(this);
-    MainWindow::getInstance()->mapWidgetOnArena(this);
-
-}
-
 void ShareBrowser::slotLayoutUpdated(){
     QItemSelectionModel *selection_model = treeView_LPANE->selectionModel();
     QModelIndexList selected  = selection_model->selectedRows(0);
