@@ -29,7 +29,6 @@
 #include <QColorGroup>
 
 #include "dcpp/stdinc.h"
-#include "dcpp/DCPlusPlus.h"
 #include "dcpp/ShareManager.h"
 #include "dcpp/Util.h"
 
@@ -253,6 +252,21 @@ int TransferViewModel::rowCount(const QModelIndex &parent) const
     return parentItem->childCount();
 }
 
+bool TransferViewModel::hasChildren(const QModelIndex &parent) const{
+    if (!parent.isValid())
+        return (rootItem->childCount() > 0);
+
+    TransferViewItem *parentItem = static_cast<TransferViewItem*>(parent.internalPointer());
+
+    if (!parentItem)
+        return false;
+
+    if (parentItem->download && parentItem->childCount() == 1)
+        return false;
+
+    return (parentItem->childCount() > 0);
+}
+
 void TransferViewModel::sort(int column, Qt::SortOrder order) {
     sortColumn = column;
     sortOrder = order;
@@ -361,7 +375,6 @@ void TransferViewModel::updateTransfer(const VarMap &params){
     }
 
     qlonglong dpos = vdbl(params["DPOS"]);
-    item->delta = (dpos - item->dpos) >= 0? (dpos - item->dpos) : 0;
     item->dpos = dpos;
     item->percent = vdbl(params["PERC"]);
     item->target = vstr(params["TARGET"]);
@@ -373,13 +386,8 @@ void TransferViewModel::updateTransfer(const VarMap &params){
             rootItem->appendChild(item);
     }
 
-    if (item->parent() != rootItem && rootItem->childItems.contains(item->parent()) && params.contains("FPOS")){
-        item->parent()->dpos += item->delta;
-        item->parent()->finished = false;
-
-        if (vlng(params["FPOS"]) > item->parent()->dpos)
-            item->parent()->dpos = vlng(params["FPOS"]);
-    }
+    if (item->parent() != rootItem && rootItem->childItems.contains(item->parent()) && params.contains("FPOS"))
+        item->parent()->dpos = vlng(params["FPOS"]);
 }
 
 void TransferViewModel::removeTransfer(const VarMap &params){
@@ -507,6 +515,7 @@ void TransferViewModel::updateParent(TransferViewItem *p){
     int active = 0;
     double speed = 0.0;
     qint64 totalSize = 0;
+    qlonglong actual = p->dpos;
     qint64 timeLeft = 0;
     double progress = 0.0;
 
@@ -525,8 +534,13 @@ void TransferViewModel::updateParent(TransferViewItem *p){
 
         if (!hubs.contains(vstr(i->data(COLUMN_TRANSFER_HOST))))
             hubs.append(vstr(i->data(COLUMN_TRANSFER_HOST)));
+
+        actual += i->dpos;
     }
 
+    if (actual <= vlng(p->data(COLUMN_TRANSFER_SIZE)))
+        p->dpos = actual;
+
     if (totalSize > 0)
         progress = (double)(p->dpos * 100.0) / totalSize;
     if (speed > 0)
@@ -592,11 +606,13 @@ void TransferViewModel::finishParent(const VarMap &params){
     p->updateColumn(COLUMN_TRANSFER_STATS, tr("Finished"));
     p->percent = 100.0;
     p->finished = true;
+    p->updateColumn(COLUMN_TRANSFER_SPEED, qlonglong(0));
 
     foreach (TransferViewItem *i, p->childItems){
         i->updateColumn(COLUMN_TRANSFER_STATS, tr("Finished"));
         i->percent = 100.0;
         i->finished = true;
+        i->updateColumn(COLUMN_TRANSFER_SPEED, qlonglong(0));
     }
 
     emit layoutChanged();
@@ -649,7 +665,6 @@ TransferViewItem::TransferViewItem(const QList<QVariant> &data, TransferViewItem
     download(false),
     percent(0.0),
     dpos(0L),
-    delta(0L),
     fail(false),
     finished(false)
 {
@@ -665,7 +680,6 @@ TransferViewItem::TransferViewItem(const TransferViewItem &item){
     fail = item.fail;
     tth = item.tth;
     finished = item.finished;
-    delta = item.delta;
 }
 void TransferViewItem::operator=(const TransferViewItem &item){
     itemData = item.itemData;
@@ -677,7 +691,6 @@ void TransferViewItem::operator=(const TransferViewItem &item){
     fail = item.fail;
     tth = item.tth;
     finished = item.finished;
-    delta = item.delta;
 }
 
 TransferViewItem::~TransferViewItem()
